/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package ability;

import gameobject.character.Character;

/**
 * Class representing an attack ability
 * @author jordan
 * @version Jan 6 2014
 */
public abstract class AttackAbility{

	
	protected float range; // radius of circle in which ability can be used
	protected int damage; // how much damage is dealt per hit
	protected int energyUse;
	protected int cooldown;
	protected int cooldownTimer;
	protected Character character;
	protected boolean activated;
	
	/**
	 * Constructor
	 * @param range the range of the attack
	 * @param damage the damage caused by the attack
	 * @param energyUse the energy used up by the attack
	 * @param cooldown the cooldown time for the attack
	 * @param character the character to whom this attack belongs
	 */
	public AttackAbility(float range, int damage, int energyUse, int cooldown,
			Character character)
	{
		this.range = range;
		this.damage = damage;
		this.energyUse = energyUse;
		this.character = character;
		this.cooldown = cooldown;
		cooldownTimer = 0;
	}
	
	/**
	 * activates the attack ability
	 * @param x the x position clicked on
	 * @param y the y position clicked on
	 */
	public void activate(float x, float y)
	{
		if(cooldownTimer <= 0)
		{
			sendAttack(x, y, range);
		}
	}
	
	/**
	 * Update the attack ability
	 * @param delta
	 */
	public void update(float delta)
	{
		if(cooldownTimer > 0)
		{
			cooldownTimer--;
		}
		if(cooldownTimer <= 0)
		{
			cooldownTimer = 0;
		}
	}
	
	/**
	 * Sends the attack (overridden by subclass)
	 * @param x the x position clicked on
	 * @param y the y position clicked on
	 * @param range the range of the attack
	 */
	protected void sendAttack(float x, float y, float range)
	{
		
	}
	
	/**
	 *  Gets the range of the attack
	 * @return range
	 */
	public float getRange()
	{
		return range;
	}
	/**
	 *  Gets how much damage the ability does
	 * @return damage
	 */
	public int getDamage()
	{
		return damage;
	}
	/**
	 *  Gets how much energy the ability drains
	 * @return energyUse
	 */
	public int getEnergyUse()
	{
		return energyUse;
	}
	
	/**
	 *  Sets the range of the attack
	 * 
	 */
	public void setRange(int x)
	{
		range = x;
	}
	/**
	 *  Sets how much damage the ability does
	 * 
	 */
	public void setDamage(int x)
	{
		damage = x;
	}
	/**
	 *  Sets how much energy the ability drains
	 * 
	 */
	public void setEnergyUse(int x)
	{
		energyUse = x;
	}
	
	/**
	 * Check if the attack ability is ready to use
	 * @return true if ready, false otherwise
	 */
	public boolean isReady()
	{
		return cooldownTimer <= 0;
	}

}
