/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package ability;

import java.util.List;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.audio.Sound;
import com.badlogic.gdx.math.Circle;

import game.GameScreen;
import game.QuestMain;
import gameobject.Explosion;
import gameobject.ObjectType;
import gameobject.character.Character;
import gameobject.character.DeadTree;

/**
 * Class representing the mage's attack ability
 * @author jordan
 * @version Jan 6 2014
 */
public class MageAttack extends AttackAbility {
	
	private float EXPLOSION_WIDTH = 0.1f;
	private float EXPLOSION_HEIGHT = 0.1f;
	private float radius;
	private boolean boss;

	/**
	 * Constructor
	 * @param range the range of the attack
	 * @param damage the damage caused by the attack
	 * @param energyUse the energy used up by the attack
	 * @param cooldown the cooldown time for the attack
	 * @param character the character to whom this attack belongs
	 */
	public MageAttack(boolean boss, float range, float radius, int damage, int energyUse,
			int cooldown, Character character) {
		super(range, damage, energyUse, cooldown, character);
		this.radius = radius;
		this.boss = boss;
	}

	//initialize the audio file
		Sound mageAttackSound = Gdx.audio.newSound(Gdx.files.internal("assets/data/sound/mageattack.wav"));
		
	/*
	 * @see ability.AttackAbility#sendAttack(float, float, float)
	 */
	@Override
	public void sendAttack(float destX, float destY, float range)
	{
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		
		List<DeadTree> trees;
		
		// check that there is enough energy
		if (character.getEnergy() >= energyUse)
		{
			cooldownTimer = cooldown;
			
			//subtract energy
			character.useEnergy(energyUse);
			
			//play sound
			mageAttackSound.play(1.0f);
			
			List<Character> opponents;
			// get correct list of opponents
			if(character.getObjectType() == ObjectType.PRIMARY || character.getObjectType() == ObjectType.SECONDARY ||
					character.getObjectType() == ObjectType.TERTIARY)
			{
				opponents = gameScreen.getEnemyList();
			}
			else
			{
				opponents = gameScreen.getAllyList();
			}

			// create an attack zone
			Circle attackZone = new Circle(destX, destY, radius);
			
			// create an explosion
			Explosion explosion = new Explosion(boss, destX - EXPLOSION_WIDTH/2.0f,
					destY - EXPLOSION_HEIGHT/2.0f, EXPLOSION_WIDTH, EXPLOSION_HEIGHT,
					ObjectType.EXPLOSION);
			// add the explosion to the game screen
			gameScreen.addNewObject(explosion);

			// if there is an opponent within the attack zone, apply damage
			for(Character opponent : opponents)
			{
				if(attackZone.contains(opponent.getX() + opponent.getWidth()/2,
						opponent.getY() + opponent.getHeight()/2))
				{
					opponent.attacked(damage, character);
				}
			}
			
			// checking for dead trees
			trees = gameScreen.getDeadTreeList();
			
			for(DeadTree object : trees)
			{
				if(attackZone.contains(object.getX() + object.getWidth()/2,
						object.getY() + object.getHeight()/2))
				{
					object.attacked(damage);
				}
			}
		}
	}

}
