/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package ability;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.audio.Sound;

import manager.CollisionManager;
import game.GameScreen;
import game.GameUtility;
import game.QuestMain;
import gameobject.ObjectType;
import gameobject.Projectile;
import gameobject.character.Character;
import gameobject.character.Direction;

/**
 * Class representing the rogue's attack
 * @author jordan
 * @version Jan 6 2014
 */
public class RogueAttack extends AttackAbility {
	
	float PROJECTILE_WIDTH = 0.03f;
	float PROJECTILE_HEIGHT = 0.03f;
	
	float PROJECTILE_SPEED = 0.006f;

	/**
	 * Constructor
	 * @param range the range of the attack
	 * @param damage the damage caused by the attack
	 * @param energyUse the energy used up by the attack
	 * @param cooldown the cooldown timer for the attack
	 * @param character the character to whom this attack belongs
	 */
	public RogueAttack(float range, int damage, int energyUse,
			int cooldown, Character character) {
		super(range, damage, energyUse, cooldown, character);
		
	}
	
	//initialize the audio file
		Sound rogueAttackSound = Gdx.audio.newSound(Gdx.files.internal("assets/data/sound/rogueattack.wav"));
		
	
	/*
	 * @see ability.AttackAbility#sendAttack(float, float, float)
	 */
	@Override
	public void sendAttack(float destX, float destY, float range)
	{
		// check that there is enough energy
		if (character.getEnergy() >= energyUse)
		{
			cooldownTimer = cooldown;
			
			character.useEnergy(energyUse);
			
			//play sound
			rogueAttackSound.play(1.0f);
		
			// decide the object type of the projectile
			ObjectType type;
			if(character.getObjectType() == ObjectType.ENEMY)
			{
				type = ObjectType.ENEMYPROJECTILE;
			}
			else
			{
				type = ObjectType.ALLYPROJECTILE;
			}
		
			float startX;
			float startY;
			
			Direction direction = GameUtility.getDirection(character, destX, destY);
			
			// figure where the projectile should start depending on direction of character
			// facing right
			if(direction == Direction.RIGHT)
			{
				startX = character.getX() + character.getWidth();
				startY = character.getY();
			}
			// facing left
			else if(direction == Direction.LEFT)
			{
				startX = character.getX() - PROJECTILE_WIDTH;
				startY = character.getY() + character.getHeight()/2.0f;
			}
			// facing up
			else if(direction == Direction.UP)
			{
				startX = character.getX() + character.getWidth()/2.0f;
				startY = character.getY() + character.getHeight();
			}
			// facing down
			else
			{
				startX = character.getX();
				startY = character.getY() - PROJECTILE_HEIGHT;
			}
			
			// make a projectile
			Projectile projectile = new Projectile(startX, startY, PROJECTILE_WIDTH, PROJECTILE_HEIGHT,
				type, destX, destY, PROJECTILE_SPEED, range, damage);
		
			// subscribe the projectile for collision events
			CollisionManager collisionManager = CollisionManager.getInstance();
			try
			{
				collisionManager.subscribeObject(projectile);
			}
			catch (Exception exception)
			{
				System.out.println(exception.getMessage());
			}
		
			// add the projectile to the game screen
			GameScreen gameScreen = QuestMain.getCurrentScreen();
			gameScreen.addNewObject(projectile);
		}
	}

}
