/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package ability;

import java.util.List;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.audio.Sound;
import com.badlogic.gdx.math.Circle;

import game.GameScreen;
import game.QuestMain;
import gameobject.ObjectType;
import gameobject.PoisonCloud;
import gameobject.character.Character;

/**
 * Class representing the rogue's special ability
 * @author jordan
 * @version Jan 6 2014
 */
public class RogueSpecial extends SpecialAbility {

	private float CLOUD_WIDTH = 0.1f;
	private float CLOUD_HEIGHT = 0.1f;

	private int damage;

	/**
	 * Constructor
	 * @param range the range of the ability
	 * @param energyUse the energy used up by the ability
	 * @param damage the damage caused by the ability
	 * @param character the character to whom the ability belongs
	 */
	public RogueSpecial(float range, int energyUse, int damage, int cooldown, Character character) {
		super(range, energyUse, cooldown, character);
		this.damage = damage;
	} 
	
	//initialize the audio file
		Sound rogueSpecialSound = Gdx.audio.newSound(Gdx.files.internal("assets/data/sound/roguespecial.wav"));
		

	/*
	 * @see ability.SpecialAbility#activate()
	 */
	@Override
	public void activate(){
		if(cooldownTimer <= 0){
			throwBomb();
		}
	}

	/*
	 * @see ability.SpecialAbility#update(float)
	 */
	public void update(float delta)
	{
		// update cooldown timer
		if(cooldownTimer > 0)
		{
			cooldownTimer--;
		}
		if(cooldownTimer <= 0)
		{
			cooldownTimer = 0;
		}
	}

	/**
	 * Throw a bomb
	 */
	public void throwBomb(){

		if(character.getEnergy() >= energyUse)
		{
			GameScreen gameScreen = QuestMain.getCurrentScreen();

			cooldownTimer = cooldown;

			//subtract energy
			character.useEnergy(energyUse);
			
			//play sound
			rogueSpecialSound.play(1.0f);

			List<Character> enemies;
			// get correct list of opponents
			if(character.getObjectType() == ObjectType.PRIMARY || character.getObjectType() == ObjectType.SECONDARY ||
					character.getObjectType() == ObjectType.TERTIARY)
			{
				enemies = gameScreen.getEnemyList();
			}
			else
			{
				enemies = gameScreen.getAllyList();
			}

			// make the attack zone
			Circle attackZone = new Circle(character.getX(), character.getY(), range);

			// create a poison cloud
			PoisonCloud poisonCloud = new PoisonCloud(character.getX() - CLOUD_WIDTH/4.0f,
					character.getY() - CLOUD_HEIGHT/4.0f, CLOUD_WIDTH, CLOUD_HEIGHT,
					ObjectType.POISON_CLOUD);
			// add the poison cloud to the screen
			gameScreen.addNewObject(poisonCloud);

			// if there is an opponent within the attack zone, apply damage
			for(Character enemy : enemies)
			{
				if(attackZone.contains(enemy.getX() + enemy.getWidth()/2,
						enemy.getY() + enemy.getHeight()/2))
				{
					enemy.takeDamage(damage);
				}		
			}
		}
	}
}
