/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package ability;

import gameobject.character.Character;

/**
 * Class representing a special ability
 * @author jordan
 * @version Jan 6 2014
 */
public class SpecialAbility{
	
	protected float range; // radius of circle in which ability can be used
	protected int energyUse;
	protected Character character;
	protected boolean activated;
	protected int cooldown;
	protected int cooldownTimer;
	
	/**
	 * Constructor
	 * @param range the range of the ability
	 * @param energyUse the energy used up by the ability
	 * @param character the character to whom this ability belongs
	 */
	public SpecialAbility(float range, int energyUse, int cooldown, Character character)
	{
		this.range = range;
		this.energyUse = energyUse;
		this.character = character;
		this.cooldown = cooldown;
		cooldownTimer = 0;
	}

	/**
	 * Activate the ability (overridden by subclass)
	 */
	public void activate() {
		
	}
	
	/**
	 * Update the ability
	 * @param delta
	 */
	public void update(float delta)
	{
		
	}

	/**
	 * Deactivate the ability (overridden by subclass)
	 */
	public void deactivate() {
		
	}
	
	/**
	 * Get the range
	 * @return the range
	 */
	public float getRange()
	{
		return range;
	}

	/**
	 * Get the energy usage
	 * @return energyUse
	 */
	public float getEnergyUse() {
		return energyUse;
	}
	
	/**
	 * Check if the attack ability is ready to use
	 * @return true if ready, false otherwise
	 */
	public boolean isReady()
	{
		return cooldownTimer <= 0;
	}

}
