/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package ability;

import java.util.ArrayList;
import java.util.List;

import manager.AIManager;

import com.badlogic.gdx.math.Circle;

import event.AIEvent;
import event.AIEventType;
import game.GameScreen;
import gameobject.GameObject;
import gameobject.ObjectType;
import gameobject.character.AnimationState;
import gameobject.character.Character;
import gameobject.character.Property;

/**
 * Class representing the warrior's special ability
 * @author jordan
 * @version Jan 6 2014
 */
public class WarriorSpecial extends SpecialAbility {

	private int duration;
	private int timer;
	private boolean active;

	/**
	 * Constructor
	 * @param range the range of the ability
	 * @param energyUse the energy used up by the ability
	 * @param duration the duration of the ability
	 * @param character the character to whom the ability belongs
	 */
	public WarriorSpecial(float range, int energyUse, int duration, int cooldown, Character character)
	{
		super(range, energyUse, cooldown, character);
		this.duration = duration;
		this.timer = 0;
		this.active = false;
	}

	/*
	 * @see ability.SpecialAbility#activate()
	 */
	@Override
	public void activate(){
		if(cooldownTimer <= 0){
			shout();
		}
	}

	/*
	 * @see ability.SpecialAbility#update(float)
	 */
	public void update(float delta)
	{
		// update cooldown timer
		if(cooldownTimer > 0)
		{
			cooldownTimer--;
		}
		if(cooldownTimer <= 0)
		{
			cooldownTimer = 0;
		}
		
		// decrement the timer
		if(timer > 0)
		{
			timer--;
		}

		// make sure the timer stops at zero
		if(timer <= 0 && active)
		{
			timer = 0;
			active = false;

			// send the event to the ai
			AIManager aiManager = AIManager.getInstance();
			AIEvent aievent = new AIEvent(character, AIEventType.END_TAUNT);
			aiManager.handleEvent(aievent);
		}
	}

	/**
	 * Causes the warrior to shout
	 */
	public void shout(){

		if(character.getEnergy() >= energyUse)
		{
			cooldownTimer = cooldown;
			
			//subtract energy
			character.useEnergy(energyUse);
			timer = duration;
			active = true;
			
			character.setCharacterState(AnimationState.SPECIAL_RIGHT);
			
			// send the event to the ai
			AIManager aiManager = AIManager.getInstance();
			AIEvent aievent = new AIEvent(character, AIEventType.TAUNT);
			aiManager.handleEvent(aievent);
		}
	}
}
