/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package game;

/**
 * Singleton class to manage the in-game passage of time
 * @author Eyleen
 */
public class Clock {
	private static Clock instance = null;
	private long time;
	private static boolean started;
	private boolean paused;
	
	/**
	 * Singleton constructor
	 */
	private Clock(){
		started = false;
		paused = false;
		time = 0;
	}
	
	public static Clock createInstance(){
		if(instance == null)
			instance = new Clock();
		return instance;
	}
	
	public static Clock getInstance(){
		return instance;
	}
	
	/**
	 * Start the clock 
	 */
	public static void start(){
		if(started){
			return;
		}
		started = true;
	}
	
	/**
	 * Mark the passage of one unit of time
	 */
	public void tick(){
		if(paused){
			return;
		}
		time++;
	}
	
	/**
	 * Pause the clock
	 */
	public void pause(){
		System.out.println("paused");
		paused = true;
	}
	
	/**
	 * Unpause the clock
	 */
	public void unpause(){
		System.out.println("unpaused");
		paused = false;
	}
	
	public boolean isPaused(){
		return paused;
	}
	
	/**
	 * @return the number of ticks since the clock started
	 */
	public long getTime(){
		return time;
	}
}