package game;

import gameobject.Dialogue;
import hud.HUD;

import java.util.ArrayList;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.InputProcessor;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;

public class DialogueHandler implements InputProcessor{
	private static DialogueHandler instance = null;
	
	private final int DURATION = 200;
	private ArrayList<Dialogue> dialogue;
	private static boolean hasEntered = false;
	private static boolean enemyDead = false;
	private static ArrayList<Integer> timer;
	private static boolean init = false;
	private static int index = 0;

	private static Clock clock = null;
	
	private DialogueHandler(){
		dialogue = new ArrayList<Dialogue>();
		timer = new ArrayList<Integer>();
		
		hasEntered = false;
		enemyDead = false;
	}
	
	public static DialogueHandler makeNewInstance(){
		instance = new DialogueHandler();
		return instance;
	}
	
	public static DialogueHandler getInstance(){
		return instance;
	}
	
	public void update(){
		if(!init || index >= dialogue.size()){
			return;
		}
		
		if (dialogue.get(index).isEmpty() || dialogue.get(index).getCurrent().requiresTrigger() || dialogue.get(index).isDone()){
			return;
		}
		
		timer.set(index, timer.get(index) + 1);
		
		if (timer.get(index) >= DURATION){
			timer.set(index, 0);	
			if(!dialogue.get(index).advance()){
				index += (index >= dialogue.size() - 1 ? 0 : 1);
			}
		}
	}
	
	public void draw(SpriteBatch spriteBatch){
		if (!init)
		{
			return;
		}
		
		dialogue.get(index).draw(spriteBatch);
	}
	
	public void onEntry()
	{
		if(!init){
			return;
		}
		
		if (hasEntered)
		{
			return;
		}
		clock.getInstance().pause();
		hasEntered = true;

		for(int i = 0; i < dialogue.size(); i++)
		{
			if(dialogue.get(i).getCurrent().getTrigger().equals("on_entry")){
				dialogue.get(i).getCurrent().clearTrigger();
				clock.getInstance().pause();
			}
		}
		
	}
	
	public void onEnemyDeath(){
		if(!init){
			return;
		}
		
		if(enemyDead){
			for(int i = 0; i < dialogue.size(); i++)
			{
				if(dialogue.get(i).getCurrent().getTrigger().equals("on_enemyDeath")){
					dialogue.get(i).getCurrent().clearTrigger();
					clock.getInstance().pause();
				}
			}
			enemyDead = false;
		}
	}
	
	public void npcCollision(String name)
	{
		if(!init){
			return;
		}		
		
		for(int i = 0; i < dialogue.size(); i++)
		{
			if(dialogue.get(i).getCurrent().getTrigger().equals("on_collision") && 
					dialogue.get(i).getCurrent().getNPC().getName().equals(name)){
				dialogue.get(i).getCurrent().clearTrigger();
				clock.getInstance().pause();
			}
		}
	}
	
	public void setEnteredFalse()
	{
		hasEntered = false;
	}
	
	public void setInitTrue(int level)
	{
		onEntry();
		
		createLevelDialogue(level);
	}
	
	public void createLevelDialogue(int level)
	{
		if (level == 0)
		{
			dialogue = new ArrayList<Dialogue>();
			timer = new ArrayList<Integer>();
			hasEntered = false;
			
			dialogue.add(new Dialogue("assets/data/dialogue/Level1_Dialogue1.txt"));
			dialogue.add(new Dialogue("assets/data/dialogue/Level1_Dialogue2.txt"));
			
			for (int i = 0; i < dialogue.size(); i++){
				timer.add(0);
			}
			
			init = true;
			index = 0;
		}
		else if (level == 1)
		{
			dialogue = new ArrayList<Dialogue>();
			timer = new ArrayList<Integer>();
			hasEntered = false;
			
			dialogue.add(new Dialogue("assets/data/dialogue/Level2_Dialogue1.txt"));
			
			for (int i = 0; i < dialogue.size(); i++)
			{
				timer.add(0);
			}
			
			init = true;
			index = 0;
		}
		else if (level == 2)
		{
			dialogue = new ArrayList<Dialogue>();
			timer = new ArrayList<Integer>();
			hasEntered = false;
			
			dialogue.add(new Dialogue("assets/data/dialogue/Level3_Dialogue1.txt"));
			dialogue.add(new Dialogue("assets/data/dialogue/Level3_Dialogue2.txt"));
			
			for (int i = 0; i < dialogue.size(); i++)
			{
				timer.add(0);
			}
			
			init = true;
			index = 0;
		}
		else if (level == 3)
		{
			dialogue = new ArrayList<Dialogue>();
			timer = new ArrayList<Integer>();
			hasEntered = false;
			
			dialogue.add(new Dialogue("assets/data/dialogue/Level4_Dialogue1.txt"));
			
			for (int i = 0; i < dialogue.size(); i++)
			{
				timer.add(0);
			}
			
			init = true;
			index = 0;
		}
		else if (level == 4)
		{
			dialogue = new ArrayList<Dialogue>();
			timer = new ArrayList<Integer>();
			hasEntered = false;
			
			dialogue.add(new Dialogue("assets/data/dialogue/Level5_Dialogue1.txt"));
			
			for (int i = 0; i < dialogue.size(); i++)
			{
				timer.add(0);
			}
			
			init = true;
			index = 0;
		}
		else if (level == 5)
		{
			dialogue = new ArrayList<Dialogue>();
			timer = new ArrayList<Integer>();
			hasEntered = false;
			
			dialogue.add(new Dialogue("assets/data/dialogue/Level6_Dialogue1.txt"));
			
			for (int i = 0; i < dialogue.size(); i++)
			{
				timer.add(0);
			}
			
			init = true;
			index = 0;
		}
		else if (level == 6)
		{
			dialogue = new ArrayList<Dialogue>();
			timer = new ArrayList<Integer>();
			hasEntered = false;
			
			dialogue.add(new Dialogue("assets/data/dialogue/Level7_Dialogue1.txt"));
			
			for (int i = 0; i < dialogue.size(); i++)
			{
				timer.add(0);
			}
			
			init = true;
			index = 0;
		}
		else{
			HUD.getInstance().unpause();
		}
	}

	@Override
	public boolean keyTyped(char character) {
		if(character == ' '){
			if (dialogue.get(index).isEmpty() || dialogue.get(index).getCurrent().requiresTrigger() || dialogue.get(index).isDone())
				return false;
				
			timer.set(index, 0);
			if(!dialogue.get(index).advance()){
				index += (index >= dialogue.size() - 1 ? 0 : 1);
				return true;
			}
		}
		return false;
	}
	
	@Override
	public boolean keyDown(int keycode) {
		return false;
	}

	@Override
	public boolean keyUp(int keycode) {
		return false;
	}

	@Override
	public boolean touchDown(int screenX, int screenY, int pointer, int button) {
		return false;
	}

	@Override
	public boolean touchUp(int screenX, int screenY, int pointer, int button) {
		return false;
	}

	@Override
	public boolean touchDragged(int screenX, int screenY, int pointer) {
		return false;
	}

	@Override
	public boolean mouseMoved(int screenX, int screenY) {
		return false;
	}

	@Override
	public boolean scrolled(int amount) {
		return false;
	}

	public boolean isFinished() {
		return (dialogue.isEmpty() || dialogue.get(index).isDone())
				|| dialogue.size() > 1;
	}
}
