/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package game;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;

/**
 * Class that handles saving and loading games
 * @author jordan, Eyleen
 * @version Jan 6 2014
 */
public class GameSaver {
	// singleton instance
	private static GameSaver instance = null;

	// the main game
	private QuestMain game;

	// path to directory of saved games
	private String saveDirectoryPath;
	//private FileHandle saveDirectory;
	// list of saved game file handles

	private FileHandle saveFile;

	/**
	 * Private constructor
	 * @param g the main class
	 * @param savePath the path to the directory of save files
	 */
	private GameSaver(QuestMain g, String savePath)
	{
		game = g;
		
		saveDirectoryPath = savePath + "saved_game_0";
		
		if(Gdx.files.isLocalStorageAvailable())
		{
			//this.saveDirectory = Gdx.files.local(saveDirectoryPath);
		}
		else
		{
			System.out.println("Cannot make local saved games directory.");
		}
		
		saveFile = new FileHandle(saveDirectoryPath);
	}

	/**
	 * Makes a new instance of this singleton
	 * @param game the main class
	 * @param saveDirectory the path to the directory of save files
	 * @return
	 */
	public static GameSaver makeNewInstance(QuestMain game, String saveDirectory)
	{
		instance = new GameSaver(game, saveDirectory);
		return instance;
	}

	/**
	 * Returns an instance of this singleton
	 * @return
	 */
	public static GameSaver getInstance()
	{
		return instance;
	}

	/**
	 * Save a new game to a file
	 */
	public void save()
	{
		// get levelpath from GameScreen
		if(QuestMain.getCurrentScreen() != null)
		{
			String levelNumber = "" + game.getCurrentLevel();
			// TODO: get upgrades from player

			// write to file
			//FileHandle saveFile = Gdx.files.local(saveDirectoryPath);
			saveFile.writeString(levelNumber, false);
		}
	}

	/**
	 * Loads a saved game with a particular number
	 * @param saveNum the number associated with the save file
	 * @throws Exception if there is not file with that number
	 */
	public void loadGame(int level) throws Exception
	{	
		
		//TODO load upgrades
		
		// make new GameScreen with data in file
		game.setScreen(level);
	}
	
	public int getFarthestLevel(){
		int levelNumber = Integer.parseInt(saveFile.readString());
		return levelNumber;
	}
}
