/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package game;

import gameobject.character.Direction;
import gameobject.character.Character;

/**
 * This class contains general purpose utility functions
 * @author jordan
 * @version Feb 9 2014
 */
public class GameUtility {
	
	/**
	 * Figure out which direction the target is from the character
	 * @param character the character
	 * @param target the target to compare to
	 * @return the direction
	 */
	public static Direction getDirection(Character character, float destX, float destY)
	{
		float diffX = destX - character.getX();
		float diffY = destY - character.getY();
		
		// facing right or left
		if(Math.abs(diffX) >= Math.abs(diffY))
		{
			// facing right
			if(diffX >= 0)
			{
				return Direction.RIGHT;
			}
			// facing left
			else
			{
				return Direction.LEFT;
			}
		}
		// facing up or down
		else
		{
			// facing up
			if(diffY >= 0)
			{
				return Direction.UP;
			}
			// facing down
			else
			{
				return Direction.DOWN;
			}
			
		}
	}
	
	/**
	 * Get the straight line distance between two points
	 * @param x the x coordinate of the start point
	 * @param y the y coordinate of the start point
	 * @param otherX the x coordinate of the end point
	 * @param otherY the y coordinate of the end point
	 * @return the distance as a float
	 */
	public static float getStraightLineDistance(float x, float y, float otherX, float otherY)
	{
		// get x displacement
		float diffX = otherX - x;
		// get y displacement
		float diffY = otherY - y;

		// calculate straight line distance
		float distance = (float) Math.sqrt(diffX*diffX + diffY*diffY);

		return distance;
	}

}
