/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package game;

import java.util.ArrayList;

import menu.EndGameScreen;
import menu.GameOverScreen;
import menu.ProgressJournal;
import pathfinding.Graph;
import menu.MainMenuScreen;
import hud.HUD;

import com.badlogic.gdx.Game;
import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;

/**
 * The main game
 * @author jordan, Kevin, Eyleen
 * @version Oct 4 2013
 */
public class QuestMain extends Game {

	private ArrayList<GameScreen> gms;
	private MainMenuScreen mm;
	private GameOverScreen go;
	private EndGameScreen eg;

	private static GameScreen currentScreen;

	private GameSaver gameSaver;

	private static int currentLevel = 0;

	public final String LEVEL_ONE = "assets/data/levels/level_1.txt";
	public final String LEVEL_TWO = "assets/data/levels/level_2.txt";
	public final String LEVEL_THREE = "assets/data/levels/level_3.txt";
	public final String LEVEL_FOUR = "assets/data/levels/level_4.txt";
	public final String LEVEL_FIVE = "assets/data/levels/level_5.txt";
	public final String LEVEL_SIX = "assets/data/levels/level_6.txt";
	public final String LEVEL_SEVEN = "assets/data/levels/level_7.txt";
	public final String LEVEL_EIGHT = "assets/data/levels/level_8.txt";
	public final String LEVEL_NINE = "assets/data/levels/level_9.txt";
	public final String LEVEL_TEN = "assets/data/levels/level_10.txt";
	public final String LEVEL_ELEVEN = "assets/data/levels/level_11.txt";
	public final String LEVEL_TWELVE = "assets/data/levels/level_12.txt";
	public final String LEVEL_THIRTEEN = "assets/data/levels/level_13.txt";
	public final String LEVEL_FOURTEEN = "assets/data/levels/level_14.txt";
	public final String LEVEL_FIFTEEN = "assets/data/levels/level_15.txt";
	public final String LEVEL_SIXTEEN = "assets/data/levels/level_16.txt";
	public final String LEVEL_SEVENTEEN = "assets/data/levels/level_17.txt";
	public final String LEVEL_EIGHTEEN = "assets/data/levels/level_18.txt";

	public final String[] LEVELS = {LEVEL_ONE, LEVEL_TWO, LEVEL_THREE, LEVEL_FOUR, LEVEL_FIVE, LEVEL_SIX, 
		LEVEL_SEVEN, LEVEL_EIGHT, LEVEL_NINE, LEVEL_TEN, LEVEL_ELEVEN, LEVEL_TWELVE, LEVEL_THIRTEEN, 
		LEVEL_FOURTEEN, LEVEL_FIFTEEN, LEVEL_SIXTEEN, LEVEL_SEVENTEEN, LEVEL_EIGHTEEN};
	
	public static final int numLevels = 18;

	public static int farthestLevel = 0;

	private String SAVE_DIRECTORY = "Saved_Games/";

	/*
	 * @see com.badlogic.gdx.ApplicationListener#create()
	 */
	@Override
	public void create() { 

		AssetLoader.makeNewInstance();
		ProgressJournal.makeNewInstance();
		gameSaver = GameSaver.makeNewInstance(this, SAVE_DIRECTORY);

		gms = new ArrayList<GameScreen>();
		
		int i = 0;
		for(String level : LEVELS)
		{
			GameScreen gm = new GameScreen(this, level, i);
			gms.add(gm);
			i++;
		}

		try {
			mm = MainMenuScreen.makeNewInstance(this);
		} catch (Exception e1) {
			e1.printStackTrace();
		}

		// start a new screen
		try {
			setScreen(mm);
		} catch (Exception e) {
			e.printStackTrace();
		}

		DialogueHandler.makeNewInstance();

		farthestLevel = gameSaver.getFarthestLevel();

		Clock.getInstance().start();
		//gameEnd();
	}

	/**
	 * Sets the new screen
	 * @param levelpath the path to the level file for the new screen
	 */
	public void setScreen(int level)
	{
		
		// game is over
		if(level >= LEVELS.length)
		{
			gameEnd();
			return;
		}

		// dispose of old screen
		if(currentScreen != null)
		{
			currentScreen.dispose();
		}
		
		// set the new screen
		currentScreen = gms.get(level);
		setScreen(currentScreen);
		currentLevel = level;

		// set the farthest level
		if(farthestLevel < level)
		{
			farthestLevel = level;
			// save the game
			gameSaver.save();
		}
	}

	public void gameEnd(){
		try{
			eg = new EndGameScreen(this);
		}catch(Exception e){
			e.printStackTrace();
		}
		Gdx.input.setInputProcessor(eg);
		eg.activate();
		setScreen(eg);
	}

	/**
	 * Go the gameover screen
	 */
	public void gameOver(){
		try{
			go = new GameOverScreen(this);
		}catch(Exception e){
			e.printStackTrace();
		}
		Gdx.input.setInputProcessor(go);
		setScreen(go);
	}

	/**
	 * Return to the main menu
	 */
	public void returnToMenu(){
		try {
			mm = MainMenuScreen.makeNewInstance(this);
		}catch(Exception e){
			e.printStackTrace();
		}
		Gdx.input.setInputProcessor(mm);
		setScreen(mm);
	}

	/**
	 * Resume the game
	 */
	public void resumeGame(){
		setScreen(currentLevel);
		Gdx.input.setInputProcessor(HUD.getMultiplexer());
	}

	public static int getCurrentLevel(){
		return currentLevel;
	}

	public static GameScreen getCurrentScreen()
	{
		return currentScreen;
	}
	
	/*
	 * @see com.badlogic.gdx.Game#render()
	 */
	public void render()
	{
		super.render();
	}

}