/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import game.Clock;
import game.DialogueHandler;
import game.GameScreen;
import game.Player;
import game.QuestMain;

import java.util.ArrayList;

import menu.ProgressJournal;
import menu.Size;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;

/**
 * Class to string textBoxes together to create dialogue
 * @author Kevin, Eyleen
 * @version Feb 19 2014
 */
public class Dialogue {
	private ArrayList<TextBox> lines;
	private int index;
	private int level;
	private NPC thisNPC;
	private boolean done;
	
	private static Clock clock = null;
	
	/**
	 * Constructor
	 * @param numLines the total number of lines
	 * @param textLines the list of text lines
	 */
	public Dialogue(String filename)
	{	
		clock = Clock.getInstance();
		lines = new ArrayList<TextBox>();
		index = 0;
		done = false;
		thisNPC = null;
		parseDialogue(filename);
		clock = Clock.getInstance();
	}
	
	private void parseDialogue(String filename)
	{
		FileHandle file = Gdx.files.internal(filename);
		String fileText = file.readString();
		String[] fileTokens = fileText.split(" |\n");
		int i = 0;
		// loop through the tokens
		while (!fileTokens[i].equals("EOF"))
		{
			String event = fileTokens[i];
			i++;
			String image = fileTokens[i];
			i++;
			String character = fileTokens[i].substring(0, fileTokens[i].length() - 1);
			i++;
			
			if (character.equals("warrior"))
			{
				lines.add(new TextBox(Player.getInstance().getWarrior(), image, 100, event));
			}
			else if (character.equals("mage"))
			{
				lines.add(new TextBox(Player.getInstance().getMage(), image, 100, event));
			}
			else if (character.equals("rogue"))
			{
				lines.add(new TextBox(Player.getInstance().getRogue(), image, 100, event));
			}
			else
			{
				if(QuestMain.getCurrentScreen().getNPC(character) != null)
				{					
					lines.add(new TextBox(QuestMain.getCurrentScreen().getNPC(character), image, 100, event));
				}
			}
		}
	}
	
	public void draw(SpriteBatch spriteBatch){
		if (done || lines.size() == 0)
		{
			return;
		}
		
		lines.get(index).draw(spriteBatch);
	}

	public boolean advance() {
		clock.pause();
		
		if(index < lines.size() - 1){
			index++;
			return true;
		}

		clock.unpause();
		done = true;
		
		ProgressJournal.onDialogue((lines.get(index).getCharacter() == null
				? "none" : lines.get(index).getCharacter().getName()),
				(lines.get(index).getNPC() == null ? "none" : lines.get(index).getNPC().getName()),
				index);
		
		return false;
	}
	
	public TextBox getCurrent(){
		return lines.get(index);
	}

	public boolean isEmpty() {
		return lines.isEmpty();
	}
	
	public boolean isDone(){
		return done;
	}
}
