/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import game.AssetLoader;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Animation;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Class representing an explosion
 * @author jordan
 * @version Jan 6 2014
 */
public class Explosion extends AbstractGameObject {

	private final int IMAGE_WIDTH = 128;
	private final int IMAGE_HEIGHT = 128;

	private final float ANIMATION_FRAME_TIME = 0.08f;

	private Animation explosionAnimation;

	private float stateTime = 0.0f;

	private boolean boss;

	/**
	 * Constructor
	 * @param x the x position of the explosion
	 * @param y the y position of the explosion
	 * @param width the width of the explosion
	 * @param height the height of the explosion
	 * @param type the type of object
	 */
	public Explosion(boolean boss, float x, float y, float width, float height, ObjectType type)
	{
		super(x, y, width, height, type);

		this.boss = boss;
		if(boss)
		{
			explosionAnimation = AssetLoader.getBossExplosion();
		}
		else
		{
			explosionAnimation = AssetLoader.getMageExplosion();
		}
	}

	/*
	 * @see gameobject.AbstractGameObject#update(float)
	 */
	@Override
	public void update(float delta)
	{
		stateTime += delta;

		// get rid of the explosion when the animation is done
		if(explosionAnimation.isAnimationFinished(stateTime))
		{
			markedForDeath = true;
		}
	}

	/*
	 * @see gameobject.AbstractGameObject#getImageToDraw()
	 */
	@Override
	public TextureRegion getImageToDraw()
	{
		return explosionAnimation.getKeyFrame(stateTime, false);
	}

}
