package gameobject;

import event.CollisionEvent;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Animation;
import com.badlogic.gdx.graphics.g2d.TextureRegion;



public class GateDoor extends AbstractGameObject{
	
	Animation openAnimation;
	boolean gateOpen;
	private float stateTime = 0.0f;
	TextureRegion image;
	
	public GateDoor(float x, float y, TextureRegion gateDoor, float width, float height, ObjectType type, 
			Animation openAnimation) {
		super(x, y, width, height, type);
		this.openAnimation = openAnimation;
		gateOpen = false;
		this.image = gateDoor;
	}
	
	@Override
	public TextureRegion getImageToDraw()
	{
		TextureRegion imageToDraw = this.image;
		if(gateOpen)
		{
			imageToDraw = openAnimation.getKeyFrame(getStateTime(), false);
		}
		
		return imageToDraw;
	}
	
	@Override
	public void update(float delta)
	{
		setStateTime(getStateTime() + delta);
	}
	
	/**
	 * Get the state time
	 * @return stateTime
	 */
	public float getStateTime() {
		return stateTime;
	}

	/**
	 * Set the state time
	 * @param stateTime the new state time
	 */
	public void setStateTime(float stateTime) {
		this.stateTime = stateTime;
	}

	public boolean isOpen()
	{
		return gateOpen;
	}
	
	public void setGateOpen()
	{
		gateOpen = true;
	}
	
	/*
	 * @see gameobject.AbstractGameObject#handleCollision(event.CollisionEvent)
	 */
	@Override
	public void handleCollision(CollisionEvent cevent) {
		GameObject otherObject = cevent.getCollidingObject();
		ObjectType type = otherObject.getObjectType();
		
		if(type == ObjectType.PRIMARY)
		{
			setGateOpen();
		}
	}
}
