/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import game.AssetLoader;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Animation;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Class representing the sparkles created by the mage's healing
 * @author jordan
 * @version Jan 6 2014
 */
public class HealingSparkles extends AbstractGameObject {

	private final int IMAGE_WIDTH = 128;
	private final int IMAGE_HEIGHT = 128;
	
	private final float DELAY_TIME = 0.2f;
	private final float ANIMATION_FRAME_TIME = 0.08f;
	
	private Animation sparklesAnimation;
	
	private float stateTime = 0.0f;
	
	private boolean boss;
	
	/**
	 * Constructor
	 * @param x the x position of the sparkles
	 * @param y the y position of the sparkles
	 * @param width the width of the sparkles
	 * @param height the height of the sparkles
	 * @param type the type of object
	 */
	public HealingSparkles(boolean boss, float x, float y, float width, float height,
			ObjectType type) {
		super(x, y, width, height, type);
		this.boss = boss;
		if(boss)
		{
			sparklesAnimation = AssetLoader.getBossSparkles();
		}
		else
		{
			sparklesAnimation = AssetLoader.getMageSparkles();
		}
	}
	
	/*
	 * @see gameobject.AbstractGameObject#update(float)
	 */
	@Override
	public void update(float delta)
	{
		stateTime += delta;
		
		if(sparklesAnimation.isAnimationFinished(stateTime))
		{
			markedForDeath = true;
		}
	}
	
	/*
	 * @see gameobject.AbstractGameObject#getImageToDraw()
	 */
	@Override
	public TextureRegion getImageToDraw()
	{
		if(stateTime > DELAY_TIME)
		{
			return sparklesAnimation.getKeyFrame(stateTime, false);
		}
		return null;
	}

}
