/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import manager.CollisionManager;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.audio.Sound;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

import event.CollisionEvent;
import game.GameScreen;
import game.Player;
import game.QuestMain;

/**
 * An item which appears after an enemy is defeated
 * @author Phoenix
 * @version Jan 6 2014
 */
public class ItemDrop extends AbstractGameObject{
	private final int ICON_PIXEL_WIDTH = 64;
	private final int ICON_PIXEL_HEIGHT = 64;
	private final static float ICON_FLOAT_WIDTH = 0.05f;
	private final static float ICON_FLOAT_HEIGHT = 0.05f;
	private final String HEALTH_POTION = "data/hud/potion-health.png";
	private final String STAMINA_POTION = "data/hud/potion-energy.png";
	
	private Texture texture;
	private TextureRegion region;
	
	private boolean potionType;

	/**
	 * Constructor
	 * @param x the x position of the item
	 * @param y the y position of the item
	 * @throws Exception if the item cannot be made
	 */
	public ItemDrop(float x, float y) throws Exception{
		super(x, y, ICON_FLOAT_WIDTH, ICON_FLOAT_HEIGHT, ObjectType.ITEM);
		
		potionType = Math.random() < .5;
		
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		
		// decide which image it should use
		if(potionType){
			texture = new Texture(Gdx.files.internal(HEALTH_POTION));
			gameScreen.addTexture(texture);
		}else{
			texture = new Texture(Gdx.files.internal(STAMINA_POTION));
			gameScreen.addTexture(texture);
		}
		
		texture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		region = new TextureRegion(texture, 0, 0,
				ICON_PIXEL_WIDTH, ICON_PIXEL_HEIGHT);
		
		// subscribe for collisions
		CollisionManager.getInstance().subscribeObject(this);
		
		objectType = ObjectType.POTION;
	}
	
	//initialize the audio file
		Sound potionUpSound = Gdx.audio.newSound(Gdx.files.internal("assets/data/sound/pickup.wav"));
		
	
	/*
	 * @see gameobject.AbstractGameObject#getImageToDraw()
	 */
	@Override
	public TextureRegion getImageToDraw(){
		return region;
	}
	
	/*
	 * @see gameobject.AbstractGameObject#handleCollision(event.CollisionEvent)
	 */
	@Override
	public void handleCollision(CollisionEvent cevent){
		ObjectType type = cevent.getCollidingObject().getObjectType();
		
		if(type == ObjectType.PRIMARY || type == ObjectType.SECONDARY || type == ObjectType.TERTIARY){
			Player p = Player.getInstance();
			
			//play sound
			potionUpSound.play(1.0f);
			
			if(potionType){
				p.addHealthPotion();
				markedForDeath = true;
			}else{
				p.addEnergyPotion();
				markedForDeath = true;
			}
		}
	}
}
