/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import java.util.ArrayList;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Animation;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

import event.CollisionEvent;
import game.DialogueHandler;
import gameobject.character.AnimationState;

/**
 * An collideable object that doesn't move
 * @author kevin
 * @version Oct 3 2013
 */
public class NPC extends AbstractGameObject{
	
	// animations
		private final int NUM_ANIMATIONS = 40;

		// movement animations
		//private Animation idleAnimation;
		private Animation movingRightAnimation;
		private Animation movingLeftAnimation;
		private Animation movingUpAnimation;
		private Animation movingDownAnimation;

		// attacking animations
		private Animation attackingRightAnimation;
		private Animation attackingLeftAnimation;
		private Animation attackingUpAnimation;
		private Animation attackingDownAnimation;

		// defending animations
		protected Animation defendingRightAnimation;
		private Animation defendingLeftAnimation;
		private Animation defendingUpAnimation;
		private Animation defendingDownAnimation;

		// idle animations
		private Animation facingRightAnimation;
		private Animation facingLeftAnimation;
		private Animation facingUpAnimation;
		private Animation facingDownAnimation;

		// dead animations
		private Animation deadRightAnimation;
		private Animation deadLeftAnimation;
		private Animation deadUpAnimation;
		private Animation deadDownAnimation;

		// special animations
		private Animation specialRightAnimation;
		private Animation specialLeftAnimation;
		private Animation specialUpAnimation;
		private Animation specialDownAnimation;

		// potion animations
		private Animation potionRightAnimation;
		private Animation potionLeftAnimation;
		private Animation potionUpAnimation;
		private Animation potionDownAnimation;

		// revive animations
		private Animation reviveRightAnimation;
		private Animation reviveLeftAnimation;
		private Animation reviveUpAnimation;
		private Animation reviveDownAnimation;

		// end defending animations
		protected Animation endDefendingRightAnimation;
		protected Animation endDefendingLeftAnimation;
		protected Animation endDefendingUpAnimation;
		protected Animation endDefendingDownAnimation;

		// pain animations
		protected Animation painRightAnimation;
		protected Animation painLeftAnimation;
		protected Animation painUpAnimation;
		protected Animation painDownAnimation;
	
	// fields
	private TextureRegion image;
	protected AnimationState characterState;
	private float stateTime = 0.0f;
	
	public int currLine;
	public String name;
	public boolean isSpeaking;
	public int speakTimer = 0;
	
	/**
	 * Constructor
	 * @param x the x position
	 * @param y the y position
	 * @param image the image to be rendered
	 * @param width the width of the object
	 * @param height the height of the object
	 * @throws Exception 
	 */
	public NPC(float x, float y, Texture image, float width, float height, String name, ArrayList<Animation> animations) throws Exception
	{
		
		super(x, y, width, height, ObjectType.NPC);
		this.name = name;
		if (width == 0.05f && height == 0.05f)
		{
			this.image = new TextureRegion(image, 0, 0, 64, 64);
		}
		else
		{
			this.image = new TextureRegion(image, 0, 0, 32, 32);
		}
		
		
		if(animations.size() != NUM_ANIMATIONS)
		{
			System.out.println(animations.size() + "  " + NUM_ANIMATIONS);
			throw new Exception("Wrong number of animations.");
		}
		makeAnimations(animations);
		characterState = AnimationState.FACING_DOWN;
	}
	
	/*
	 * @see gameobject.AbstractGameObject#getImageToDraw()
	 */
	@Override
	public TextureRegion getImageToDraw()
	{
		TextureRegion image = facingRightAnimation.getKeyFrame(getStateTime(), true);
		
		switch(characterState)
		{
		case MOVING_RIGHT:
			image = movingRightAnimation.getKeyFrame(getStateTime(), true);
			break;
		case FACING_RIGHT:
			image = facingRightAnimation.getKeyFrame(getStateTime(), true);
			break;
		case MOVING_LEFT:
			image = movingLeftAnimation.getKeyFrame(getStateTime(), true);
			break;
		case FACING_LEFT:
			image = facingLeftAnimation.getKeyFrame(getStateTime(), true);
			break;
		case MOVING_UP:
			image = movingUpAnimation.getKeyFrame(getStateTime(), true);
			break;
		case FACING_UP:
			image = facingUpAnimation.getKeyFrame(getStateTime(), true);
			break;
		case MOVING_DOWN:
			image = movingDownAnimation.getKeyFrame(getStateTime(), true);
			break;
		case FACING_DOWN:
			image = facingDownAnimation.getKeyFrame(getStateTime(), true);
			break;
		case ATTACKING_LEFT:
			image = attackingLeftAnimation.getKeyFrame(getStateTime(), false);
			break;
		case ATTACKING_RIGHT:
			image = attackingRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case ATTACKING_UP:
			image = attackingUpAnimation.getKeyFrame(getStateTime(), false);
			break;
		case ATTACKING_DOWN:
			image = attackingDownAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEFENDING_RIGHT:
			image = defendingRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEFENDING_LEFT:
			image = defendingLeftAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEFENDING_UP:
			image = defendingUpAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEFENDING_DOWN:
			image = defendingDownAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEAD_RIGHT:
			image = deadRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEAD_LEFT:
			image = deadLeftAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEAD_UP:
			image = deadUpAnimation.getKeyFrame(getStateTime(), false);
			break;
		case DEAD_DOWN:
			image = deadDownAnimation.getKeyFrame(getStateTime(), false);
			break;
		case SPECIAL_RIGHT:
			image = specialRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case SPECIAL_LEFT:
			image = specialLeftAnimation.getKeyFrame(getStateTime(), false);
			break;
		case SPECIAL_UP:
			image = specialUpAnimation.getKeyFrame(getStateTime(), false);
			break;
		case SPECIAL_DOWN:
			image = specialDownAnimation.getKeyFrame(getStateTime(), false);
			break;
		case POTION_RIGHT:
			image = potionRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case POTION_LEFT:
			image = potionLeftAnimation.getKeyFrame(getStateTime(), false);
			break;
		case POTION_UP:
			image = potionUpAnimation.getKeyFrame(getStateTime(), false);
			break;
		case POTION_DOWN:
			image = potionDownAnimation.getKeyFrame(getStateTime(), false);
			break;
		case REVIVE_RIGHT:
			image = reviveRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case REVIVE_LEFT:
			image = reviveLeftAnimation.getKeyFrame(getStateTime(), false);
			break;
		case REVIVE_UP:
			image = reviveUpAnimation.getKeyFrame(getStateTime(), false);
			break;
		case REVIVE_DOWN:
			image = reviveDownAnimation.getKeyFrame(getStateTime(), false);
			break;
		case END_DEFEND_RIGHT:
			image = endDefendingRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case END_DEFEND_LEFT:
			image = endDefendingRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case END_DEFEND_UP:
			image = endDefendingRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		case END_DEFEND_DOWN:
			image = endDefendingRightAnimation.getKeyFrame(getStateTime(), false);
			break;
		}

		return image;
	}
	
	/*
	 * @see gameobject.AbstractGameObject#handleCollision(event.CollisionEvent)
	 */
	@Override
	public void handleCollision(CollisionEvent cevent)
	{
		GameObject otherObject = cevent.getCollidingObject();
		ObjectType type = otherObject.getObjectType();
		
		// make the NPC speak if the player collides with it
		if (type == ObjectType.PRIMARY)
		{
			DialogueHandler.getInstance().npcCollision(name);
		}
	}

	public String getName() {
		return name;
	}
	
	/**
	 * Makes the the animations
	 */
	private void makeAnimations(ArrayList<Animation>animations)
	{
		// should match the order of animations in GameScreen.makePartyMember
		// also make sure to update NUM_ANIMATIONS
		movingRightAnimation = animations.get(0);
		facingRightAnimation = animations.get(1);
		movingLeftAnimation = animations.get(2);
		facingLeftAnimation = animations.get(3);
		movingUpAnimation = animations.get(4);
		facingUpAnimation = animations.get(5);
		movingDownAnimation = animations.get(6);
		facingDownAnimation = animations.get(7);
		attackingRightAnimation = animations.get(8);
		attackingLeftAnimation = animations.get(9);
		attackingUpAnimation = animations.get(10);
		attackingDownAnimation = animations.get(11);
		defendingRightAnimation = animations.get(12);
		defendingLeftAnimation = animations.get(13);
		defendingUpAnimation = animations.get(14);
		defendingDownAnimation = animations.get(15);
		deadRightAnimation = animations.get(16);
		deadLeftAnimation = animations.get(17);
		deadUpAnimation = animations.get(18);
		deadDownAnimation = animations.get(19);
		specialRightAnimation = animations.get(20);
		specialLeftAnimation = animations.get(21);
		specialUpAnimation = animations.get(22);
		specialDownAnimation = animations.get(23);
		potionRightAnimation = animations.get(24);
		potionLeftAnimation = animations.get(25);
		potionUpAnimation = animations.get(26);
		potionDownAnimation = animations.get(27);
		reviveRightAnimation = animations.get(28);
		reviveLeftAnimation = animations.get(29);
		reviveUpAnimation = animations.get(30);
		reviveDownAnimation = animations.get(31);
		endDefendingRightAnimation = animations.get(32);
		endDefendingLeftAnimation = animations.get(33);
		endDefendingUpAnimation = animations.get(34);
		endDefendingDownAnimation = animations.get(35);	
		painRightAnimation = animations.get(36);
		painLeftAnimation = animations.get(37);
		painUpAnimation = animations.get(38);
		painDownAnimation = animations.get(39);
	}
	
	/**
	 * Get the state time
	 * @return stateTime
	 */
	public float getStateTime() {
		return stateTime;
	}
	
	/**
	 * Set the state time
	 * @param stateTime the new state time
	 */
	public void setStateTime(float stateTime) {
		this.stateTime = stateTime;
	}
	
	/*
	 * @see gameobject.AbstractGameObject#update(float)
	 */
	@Override
	public void update(float delta)
	{
		setStateTime(getStateTime() + delta);
	}
}
