/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import game.AssetLoader;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Animation;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Class representing the poison cloud from the rogue's bomb
 * @author jordan
 * @version Jan 6 2014
 */
public class PoisonCloud extends AbstractGameObject {

	private final int IMAGE_WIDTH = 256;
	private final int IMAGE_HEIGHT = 256;
	
	private final float DELAY_TIME = 0.2f;
	private final float ANIMATION_FRAME_TIME = 0.08f;
	
	private Animation poisonCloudAnimation;
	
	private float stateTime = 0.0f;
	
	/**
	 * Constructor
	 * @param x the position of the cloud
	 * @param y the y position of the cloud
	 * @param width the width of the cloud
	 * @param height the height of the cloud
	 * @param type the type of object
	 */
	public PoisonCloud(float x, float y, float width, float height,
			ObjectType type) {
		super(x, y, width, height, type);
		
		poisonCloudAnimation = AssetLoader.getPoisonCloudAnimation();
	}
	
	/*
	 * @see gameobject.AbstractGameObject#update(float)
	 */
	@Override
	public void update(float delta)
	{
		stateTime += delta;
		
		if(poisonCloudAnimation.isAnimationFinished(stateTime))
		{
			markedForDeath = true;
		}
	}
	
	/*
	 * @see gameobject.AbstractGameObject#getImageToDraw()
	 */
	@Override
	public TextureRegion getImageToDraw()
	{
		if(stateTime > DELAY_TIME)
		{
			return poisonCloudAnimation.getKeyFrame(stateTime, false);
		}
		return null;
	}

}
