/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * An collideable object that doesn't move
 * @author kevin, jordan
 * @version Oct 3 2013
 */
public class SolidObject extends AbstractGameObject{
	
	// fields
	private TextureRegion image;
	
	/**
	 * Constructor
	 * @param x the x position
	 * @param y the y position
	 * @param image the image to be rendered
	 * @param width the width of the object
	 * @param height the height of the object
	 */
	public SolidObject(float x, float y, Texture image, float width, float height, ObjectType type)
	{
		super(x, y, width, height, type);
		int newWidth = 0;
		int newHeight = 0;
		// conversion
		if (width == 0.1f)
		{
			newWidth = 128;
		}
		else if (width == 0.05f)
		{
			newWidth = 64;
		}
		else
		{
			newWidth = 64;
		}
		
		// height conversion
		if (height == 0.1f)
		{
			newHeight = 128;
		}
		else if (height == 0.05f)
		{
			newHeight = 64;
		}
		else
		{
			newHeight = 64;
		}
		
		
		this.setImage(new TextureRegion(image, 0, 0, newWidth, newHeight));
	}
	
	/*
	 * @see gameobject.AbstractGameObject#getImageToDraw()
	 */
	@Override
	public TextureRegion getImageToDraw()
	{
		return getImage();
	}

	public TextureRegion getImage() {
		return image;
	}

	public void setImage(TextureRegion image) {
		this.image = image;
	}

}
