/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

import menu.Size;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

import game.GameScreen;
import game.QuestMain;
import gameobject.character.Character;

/**
 * An collideable object that doesn't move
 * @author Kevin, Eyleen, Jordan
 * @version Feb 19 2014
 */
public class TextBox{
	
	private final float SIZE_X = 0.25f;;
	private final float SIZE_Y = 0.08f;
	private final float X;
	private final float Y;
	
	// fields
	private TextureRegion image;
	private Character character = null;
	private NPC npc = null;
	private int duration;
	private String trigger;
	
	/**
	 * Constructor
	 * @param x the x position
	 * @param y the y position
	 * @param image the image to be rendered
	 * @param width the width of the object
	 * @param height the height of the object
	 * @return 
	 */
	public TextBox(Character c, String fileName, int d, String t){
		Texture texture = new Texture(fileName);
		image = new TextureRegion(texture, 0, 0, Size.QUARTERSCREEN, Size.ICON);
		duration = d;
		this.character = c;
		trigger = t;
		
		X = c.getX() + 0.06f;
		Y = c.getY() - 0.025f;
	}
	
	/**
	 * Constructor
	 * @param x the x position
	 * @param y the y position
	 * @param image the image to be rendered
	 * @param width the width of the object
	 * @param height the height of the object
	 * @return 
	 */
	public TextBox(NPC npc, String fileName, int d, String t){
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		Texture texture = new Texture(fileName);
		gameScreen.addTexture(texture);
		texture.setFilter(TextureFilter.Linear,	 TextureFilter.Linear);
		image = new TextureRegion(texture, 0, 0, Size.QUARTERSCREEN, Size.ICON);
		duration = d;
		this.npc = npc;
		trigger = t;
		
		X = npc.getX() + 0.06f;
		Y = npc.getY() - 0.025f;
	}
	
	public int getDuration(){
		return duration;
	}
	
	public String getTrigger()
	{
		return trigger;
	}
	
	public void draw(SpriteBatch spriteBatch){
		
		if(!trigger.equals("none"))
		{
			return;
		}
		
		spriteBatch.draw(image, X, Y, SIZE_X, SIZE_Y);
	}
	
	public void clearTrigger() {
		trigger = "none";
	}
	
	public Character getCharacter(){
		return character;
	}
	
	public NPC getNPC()
	{
		return npc;
	}
	
	public boolean requiresTrigger()
	{
		return !trigger.equals("none");
	}
}
