/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;

/**
 * Class representing a text object to be displayed for a period of time
 * @author jordan
 * @version Oct 10 2013
 */
public class TextObject {
	
	private int TIME_TO_DISPLAY = 1000;
	
	private String text;
	GameObject speaker;
	
	private int timer;
	
	/**
	 * Constructor
	 * @param speaker the object that's producing the text
	 * @param text the string to be displayed
	 */
	public TextObject(GameObject speaker, String text)
	{
		this.speaker = speaker;
		this.text = text;
		timer = TIME_TO_DISPLAY;
	}
	
	/**
	 * Decrement and return the value of the timer
	 * @return the value of the timer
	 */
	public int decrementTimer()
	{
		timer--;
		return timer;
	}
	
	/**
	 * Gets the string to be displayed
	 * @return the string
	 */
	public String getText()
	{
		return text;
	}
	
	/**
	 * Gets the x position of the text
	 * @return the x position
	 */
	public float getX()
	{
		return speaker.getX();
	}
	
	/**
	 * Gets the y position of the text
	 * @return the y position
	 */
	public float getY()
	{
		return speaker.getY();
	}
	
	/**
	 * Gets the speaker object
	 * @return the speaker
	 */
	public GameObject getSpeaker()
	{
		return speaker;
	}

}
