/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject;


import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

import event.CollisionEvent;
import game.GameScreen;
import game.QuestMain;
import hud.HUD;

/**
 * Object representing a screen transition
 * @author jordan, Kevin
 * @version Oct 4 2013
 */
public class TransitionObject extends AbstractGameObject {
	
	// fields
	private TextureRegion image;
	private boolean switchScreen;
	
	/**
	 * Constructor
	 * @param x the starting x position
	 * @param y the starting y position
	 * @param image the image to be drawn
	 * @param width the width of the object
	 * @param height the height of the object
	 */
	public TransitionObject(float x, float y, Texture image, float width, float height)
	{
		super(x, y, width, height, ObjectType.TRANSITION);
		this.image = new TextureRegion(image, 0, 0, 64, 64);
		switchScreen = false;
	}

	/*
	 * @see gameobject.AbstractGameObject#update(float)
	 */
	@Override
	public void update(float delta) {
		// TODO
	}

	/*
	 * @see gameobject.AbstractGameObject#getImageToDraw()
	 */
	@Override
	public TextureRegion getImageToDraw() {
		return image;
	}

	/*
	 * @see gameobject.AbstractGameObject#handleCollision(event.CollisionEvent)
	 */
	@Override
	public void handleCollision(CollisionEvent cevent) {
		//needs to make a new scene
		GameObject collidingObject = cevent.getCollidingObject();
		
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		int numEnemies = gameScreen.getNumEnemiesLeft();
		boolean dialogueFinished = gameScreen.isDialogueFinished();
		
		// switch screen if no more enemies are left, and the player collides with the transition object
		if(collidingObject.getObjectType() == ObjectType.PRIMARY && numEnemies <= 0 && dialogueFinished)
		{
			switchScreen = true;
		}
		
		if(!dialogueFinished){
			HUD.alert();
		}
	}
	
	/**
	 * Returns true if it is time to switch screens
	 * @return true to switch screens, false otherwise
	 */
	public boolean switchScreen()
	{
		return switchScreen;
	}

}
