/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package gameobject.character;

import gameobject.ObjectType;

import java.util.ArrayList;

import ability.MageAttack;
import ability.MageDefend;
import ability.MageSpecial;
import ability.RogueAttack;
import ability.RogueDefend;
import ability.RogueSpecial;
import ability.WarriorAttack;
import ability.WarriorDefend;
import ability.WarriorSpecial;

import com.badlogic.gdx.graphics.g2d.Animation;

/**
 * Class representing a boss, which is a special type of enemy
 * @author jordan
 *
 */
public class BigBoss extends Enemy {
	
	final private float MAGE_ATTACK_RANGE = 0.4f;
	final private float MAGE_ATTACK_RADIUS = 0.10f;
	final private int MAGE_ATTACK_DAMAGE = 40;
	final private int MAGE_ATTACK_ENERGY_USE = 40;
	final private int MAGE_ATTACK_COOLDOWN = 60;
	final private float MAGE_DEFEND_ENERGY_USE = 0.5f;
	final private float MAGE_SPECIAL_RANGE = 0.2f;
	final private int MAGE_SPECIAL_ENERGY_USE = 50;
	final private int MAGE_SPECIAL_HEALING = 50;
	final private int MAGE_SPECIAL_COOLDOWN = 100;
	final private int MAGE_MAX_HEALTH = 300;
	final private int MAGE_MAX_ENERGY = 200;
	final private float MAGE_ENERGY_REGEN = 0.2f;

	/**
	 * Constructor
	 * @param x the starting x position
	 * @param y the starting y position
	 * @param startingState the starting animation state
	 * @param width the width of the object
	 * @param height the height of the object
	 * @param objectType the type of the object
	 * @param characterType the type of character
	 * @param animations the set of animations
	 * @throws Exception
	 */
	public BigBoss(float x, float y, AnimationState startingState, float width, float height,
			ObjectType objectType, CharacterType characterType, ArrayList<Animation> animations) throws Exception
	{
		super(x, y, startingState, width, height, objectType, characterType, animations);
		speed = 0.003f;

		name = "Big Boss";
		attackAbility = new MageAttack(true, MAGE_ATTACK_RANGE, MAGE_ATTACK_RADIUS, MAGE_ATTACK_DAMAGE,
				MAGE_ATTACK_ENERGY_USE, MAGE_ATTACK_COOLDOWN, this);
		defendAbility = new MageDefend(MAGE_DEFEND_ENERGY_USE, this);
		specialAbility = new MageSpecial(true, MAGE_SPECIAL_RANGE,
				MAGE_SPECIAL_ENERGY_USE, MAGE_SPECIAL_HEALING, MAGE_SPECIAL_COOLDOWN, this);
		maxHealth = MAGE_MAX_HEALTH;
		maxEnergy = MAGE_MAX_ENERGY;
		energyRegen = MAGE_ENERGY_REGEN;

		health = maxHealth;
		energy = maxEnergy;
	}

}
