/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package hud;

import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import gameobject.character.PartyMember;

/**
 * Displays a group of ability icons
 * @author Phoenix
 */
public class AbilityTray{
	private final float ABILITY_X;
	private final float ABILITY_Y;
	private final float ABILITY_OFFSET_Y = 0.06f;
	
	private AbilityIcon[] tray;
	private PartyMember character;
	
	public AbilityTray(String topFileName, String topAltFileName,
			String midFileName, String midAltFileName, String botFileName,
			String botAltFileName, String botCooldownFileName, PartyMember c,
			float x, float y){
		ABILITY_X = x;
		ABILITY_Y = y;
		character = c;
		tray = new AbilityIcon[3];

		tray[0] = new AttackIcon(topFileName, topAltFileName, c.getAttackAbility(),
				x, y);
		tray[1] = new DefendIcon(midFileName, midAltFileName, c.getDefendAbility(),
				x, y - ABILITY_OFFSET_Y);
		tray[2] = new SpecialIcon(botFileName, botAltFileName, botCooldownFileName,
				c.getSpecialAbility(), x, y - (2 * ABILITY_OFFSET_Y));
	}
	
	public void draw(SpriteBatch spriteBatch){
		if(!character.isActivePartyMember()){
			return;
		}
		
		for(int i = 0; i < tray.length; i++){
				AbilityIcon a = tray[i];
				
				spriteBatch.draw(a.getRegion(), ABILITY_X, ABILITY_Y
						- (i * ABILITY_OFFSET_Y), a.getWidth(), a.getHeight());
		}
	}
	
	public void update() {	
		for(int i = 0; i < tray.length; i++){
				tray[i].update();
		}
	}
}
