/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package hud;

import game.GameScreen;
import game.QuestMain;
import menu.Size;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Displays an image of a given digit
 * @author Phoenix
 */
public class DigitIcon{
	private final String ZERO_BLACK = "assets/data/digits/zero-black.png";
	private final String ZERO_WHITE = "assets/data/digits/zero-white.png";
	private final String ONE_BLACK = "assets/data/digits/one-black.png";
	private final String ONE_WHITE = "assets/data/digits/one-white.png";
	private final String TWO_BLACK = "assets/data/digits/two-black.png";
	private final String TWO_WHITE = "assets/data/digits/two-white.png";
	private final String THREE_BLACK = "assets/data/digits/three-black.png";
	private final String THREE_WHITE = "assets/data/digits/three-white.png";
	private final String FOUR_BLACK = "assets/data/digits/four-black.png";
	private final String FOUR_WHITE = "assets/data/digits/four-white.png";
	private final String FIVE_BLACK = "assets/data/digits/five-black.png";
	private final String FIVE_WHITE = "assets/data/digits/five-white.png";
	private final String SIX_BLACK = "assets/data/digits/six-black.png";
	private final String SIX_WHITE = "assets/data/digits/six-white.png";
	private final String SEVEN_BLACK = "assets/data/digits/seven-black.png";
	private final String SEVEN_WHITE = "assets/data/digits/seven-white.png";
	private final String EIGHT_BLACK = "assets/data/digits/eight-black.png";
	private final String EIGHT_WHITE = "assets/data/digits/eight-white.png";
	private final String NINE_BLACK = "assets/data/digits/nine-black.png";
	private final String NINE_WHITE = "assets/data/digits/nine-white.png";
	
	private final float DIGIT_X;
	private final float DIGIT_Y;
	private final float DIGIT_SIZE_X = 0.05f;
	private final float DIGIT_SIZE_Y = 0.05f;
	
	private final float DIGIT_SCALE;
	
	private Texture zeroTexture;
	private Texture oneTexture;
	private Texture twoTexture;
	private Texture threeTexture;
	private Texture fourTexture;
	private Texture fiveTexture;
	private Texture sixTexture;
	private Texture sevenTexture;
	private Texture eightTexture;
	private Texture nineTexture;
	private TextureRegion region;
	
	private int number;
	
	/**
	 * Constructor
	 * @param x x-coordinate
	 * @param y y-coordinate
	 * @param n digit to display
	 */
	public DigitIcon(float x, float y, int n, float scale, String color){
		DIGIT_X = x;
		DIGIT_Y = y;
		DIGIT_SCALE = scale;
		
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		
		if(color.equals("black")){
			zeroTexture = new Texture(Gdx.files.internal(ZERO_BLACK));
			oneTexture = new Texture(Gdx.files.internal(ONE_BLACK));
			twoTexture = new Texture(Gdx.files.internal(TWO_BLACK));
			threeTexture = new Texture(Gdx.files.internal(THREE_BLACK));
			fourTexture = new Texture(Gdx.files.internal(FOUR_BLACK));
			fiveTexture = new Texture(Gdx.files.internal(FIVE_BLACK));
			sixTexture = new Texture(Gdx.files.internal(SIX_BLACK));
			sevenTexture = new Texture(Gdx.files.internal(SEVEN_BLACK));
			eightTexture = new Texture(Gdx.files.internal(EIGHT_BLACK));
			nineTexture = new Texture(Gdx.files.internal(NINE_BLACK));
		}else{
			zeroTexture = new Texture(Gdx.files.internal(ZERO_WHITE));
			oneTexture = new Texture(Gdx.files.internal(ONE_WHITE));
			twoTexture = new Texture(Gdx.files.internal(TWO_WHITE));
			threeTexture = new Texture(Gdx.files.internal(THREE_WHITE));
			fourTexture = new Texture(Gdx.files.internal(FOUR_WHITE));
			fiveTexture = new Texture(Gdx.files.internal(FIVE_WHITE));
			sixTexture = new Texture(Gdx.files.internal(SIX_WHITE));
			sevenTexture = new Texture(Gdx.files.internal(SEVEN_WHITE));
			eightTexture = new Texture(Gdx.files.internal(EIGHT_WHITE));
			nineTexture = new Texture(Gdx.files.internal(NINE_WHITE));
		}
		
		gameScreen.addTexture(zeroTexture);
		gameScreen.addTexture(oneTexture);
		gameScreen.addTexture(twoTexture);
		gameScreen.addTexture(threeTexture);
		gameScreen.addTexture(fourTexture);
		gameScreen.addTexture(fiveTexture);
		gameScreen.addTexture(sixTexture);
		gameScreen.addTexture(sevenTexture);
		gameScreen.addTexture(eightTexture);
		gameScreen.addTexture(nineTexture);
		
		zeroTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		oneTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		twoTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		threeTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		fourTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		fiveTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		sixTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		sevenTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		eightTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		nineTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		region = new TextureRegion(zeroTexture, 0, 0, Size.ICON, Size.ICON);
		
		number = n;
	}
	
	public void update(int n){
		number = n;
		
		if(number == 0){
			region.setRegion(zeroTexture);
		}else if(number == 1){
			region.setRegion(oneTexture);
		}else if(number == 2){
			region.setRegion(twoTexture);
		}else if(number == 3){
			region.setRegion(threeTexture);
		}else if(number == 4){
			region.setRegion(fourTexture);
		}else if(number == 5){
			region.setRegion(fiveTexture);
		}else if(number == 6){
			region.setRegion(sixTexture);
		}else if(number == 7){
			region.setRegion(sevenTexture);
		}else if(number == 8){
			region.setRegion(eightTexture);
		}else if(number == 9){
			region.setRegion(nineTexture);
		}
	}
	
	/**
	 * sets the digit icon to n
	 * will clap if n < 0 or n > 9
	 * @param n
	 */
	public void setNumber(int n){
		if(n < 0){
			number = 0;
		}else if(n > 9){
			number = 9;
		}else{
			number = n;
		}
	}
	
	/**
	 * increases number by one
	 * @return true if number is increased
	 */
	public boolean increase(){
		if(number < 9){
			number++;
			return true;
		}
		return false;
	}
	
	/**
	 * decreases number by one
	 * @return true if number is decreased
	 */
	public boolean decrease(){
		if(number > 0){
			number--;
			return true;
		}
		return false;
	}
	
	public void draw(SpriteBatch spriteBatch){
		update(number);
		spriteBatch.draw(region, DIGIT_X, DIGIT_Y, 0, 0, DIGIT_SIZE_X,
				DIGIT_SIZE_Y, DIGIT_SCALE, DIGIT_SCALE, 0.0f);
	}
}
