/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package hud;

import game.GameScreen;
import game.QuestMain;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

public class ItemIcon{
	private final String ITEM;
	private final float ICON_X;
	private final float ICON_Y;
	private final float ICON_SIZE_X = 0.05f;
	private final float ICON_SIZE_Y = 0.05f;
	private final int ICON_WIDTH = 64;
	private final int ICON_HEIGHT = 64;

	private Texture itemIconTexture;
	private TextureRegion itemIconRegion;
	private DigitIcon digit;
	
	public ItemIcon(String fileName, float x, float y, int n){
		ICON_X = x;
		ICON_Y = y;
		ITEM = fileName;
		
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		
		itemIconTexture = new Texture(Gdx.files.internal(ITEM));
		gameScreen.addTexture(itemIconTexture);
		itemIconRegion = new TextureRegion(itemIconTexture, 0, 0,
				ICON_WIDTH, ICON_HEIGHT);
		
		digit = new DigitIcon(x, y, n, 0.5f, "white");
	}
	
	public void draw(SpriteBatch spriteBatch){
		spriteBatch.draw(itemIconRegion, ICON_X, ICON_Y, ICON_SIZE_X, ICON_SIZE_Y);
		digit.draw(spriteBatch);
	}
	
	public void update(int n){
		digit.update(n);
	}
	
	public TextureRegion getRegion(){
		return itemIconRegion;
	}
	
	public boolean increase(){
		return digit.increase();
	}
	
	public boolean decrease(){
		return digit.decrease();
	}

	public float getX() {
		return ICON_X;
	}

	public float getY() {
		return ICON_Y;
	}

	public float getSizeX() {
		return ICON_SIZE_X;
	}

	public float getSizeY() {
		return ICON_SIZE_Y;
	}
}
