/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package hud;

import menu.Size;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

import game.GameScreen;
import game.QuestMain;
import gameobject.character.PartyMember;

public class ModeIcon{
	private final float X;
	private final float Y;
	private final float FRAME_SIZE_X = 0.028f;
	private final float FRAME_SIZE_Y = 0.028f;
	private final String DEACTIVED;
	private final String UNSELECTED;
	private final String SELECTED;
	
	private Texture deactivatedTexture;
	private Texture unselectedTexture;
	private Texture selectedTexture;
	private TextureRegion modeIconRegion;
	private PartyMember character;

	public ModeIcon(String fileDe, String fileUn, String fileSel, PartyMember c,
			float x, float y){
		X = x;
		Y = y;
		DEACTIVED = fileDe;
		UNSELECTED = fileUn;
		SELECTED = fileSel;
		
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		
		deactivatedTexture = new Texture(Gdx.files.internal(DEACTIVED));
		gameScreen.addTexture(deactivatedTexture);
		unselectedTexture = new Texture(Gdx.files.internal(UNSELECTED));
		gameScreen.addTexture(unselectedTexture);
		selectedTexture = new Texture(Gdx.files.internal(SELECTED));
		gameScreen.addTexture(selectedTexture);
		
		modeIconRegion = new TextureRegion(unselectedTexture, 0, 0,
				Size.ICON, Size.ICON);
		
		character = c;
	}
	
	public void update(){
		if(character.isActivePartyMember()){
			modeIconRegion.setRegion(deactivatedTexture);
		}else{
			//TODO add once connector points exist
			modeIconRegion.setRegion(selectedTexture);
		}
	}
	
	public void draw(SpriteBatch spriteBatch){
		spriteBatch.draw(modeIconRegion, X, Y, FRAME_SIZE_X, FRAME_SIZE_Y);
	}
}
