/*******************************************************************************

 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package hud;

import game.GameScreen;
import game.QuestMain;
import menu.Size;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * This class handles the displaying of the characters' health and energy
 * stats
 * @author Eyleen
 * @version Jan 12 2014
 */
public class StatusBar{
	private final String BAR;
	private final float BAR_X;
	private final float BAR_Y;
	private final float BAR_SIZE_X = 0.14f;
	private final float BAR_SIZE_Y = 0.03f;
		
	private TextureRegion barRegion;
	
	/**
	 * Constructor
	 * @param fileName of the bar
	 * @param x bar location, x-coordination
	 * @param y bar location, y-coordination
	 */
	public StatusBar(String fileName, float x, float y){
		BAR_X = x;
		BAR_Y = y;
		BAR = fileName;
		
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		
		Texture barTexture = new Texture(Gdx.files.internal(BAR));
		gameScreen.addTexture(barTexture);
		
		barRegion = new TextureRegion(barTexture, 0, 0, Size.PORTRAIT, Size.TINY);
	}
	
	public void draw(SpriteBatch spriteBatch, float current, float max){
		spriteBatch.draw(barRegion, BAR_X, BAR_Y, 0, 0, BAR_SIZE_X, BAR_SIZE_Y,
				0.85f * (current / max), 0.6f, 0.0f);
	}
}
