/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package manager;

import event.AIEvent;
import gameobject.character.PartyMember;

import java.util.ArrayList;
import java.util.List;

import strategy.GoalManager;

/**
 * Manages sending ai events to the goal managers
 * @author jordan
 * @version Feb 17 2014
 */
public class AIManager {
	
	private static AIManager instance = null;
	
	private List<GoalManager> goalManagers;
	
	private PartyMember commanded;
	
	/**
	 * Constructor
	 */
	protected AIManager()
	{
		goalManagers = new ArrayList<GoalManager>();
	}
	
	public static AIManager getInstance()
	{
		if (instance == null)
		{
			instance = new AIManager();
		}
		return instance;
	}
	
	public static AIManager getNewInstance()
	{
		instance = new AIManager();
		return instance;
	}
	
	/**
	 * Subscribe a goal manager to receive ai events
	 * @param goalManager
	 */
	public void subscribeObject(GoalManager goalManager)
	{
		if(!goalManagers.contains(goalManager))
		{
			goalManagers.add(goalManager);
		}
	}
	
	/**
	 * Un-subscribe a goal manager
	 * @param object
	 */
	public void unsubscribeObject(GoalManager goalManager)
	{
		if(goalManagers.contains(goalManager))
		{
			goalManagers.remove(goalManager);
		}
	}
	
	/**
	 * Handles ai events and sends them to the goal managers
	 * @param aievent
	 */
	public void handleEvent(AIEvent aievent)
	{
		for(GoalManager goalManager : goalManagers)
		{
			goalManager.handleEvent(aievent);
		}
	}
	
	/**
	 * Update the AI manager
	 * @param delta
	 */
	public void update(float delta)
	{
		
	}

}
