/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package manager;

import event.CollisionEvent;
import gameobject.character.Character;

import java.util.ArrayList;

/**
 * Manages sightings between characters, warns characters when other characters enter their line of sight
 * @author jordan
 * @version Oct 3 2013
 */
public class LineOfSightManager {
	
	private ArrayList<Character> characters;
	
	/**
	 * Constructor
	 */
	public LineOfSightManager()
	{
		characters = new ArrayList<Character>();
	}
	
	/**
	 * Subscribe a character to receive lineofsight events
	 * @param newCharacter
	 * @throws Exception if character is already subscribed
	 */
	public void subscribeCharacter(Character newCharacter) throws Exception
	{
		if(!characters.contains(newCharacter))
		{
			characters.add(newCharacter);
		}
		else
		{
			throw new Exception("Character is already subscribed to receive lineofsight events.");
		}
	}
	
	/**
	 * Un-subscribe a character
	 * @param character the character to be un-subscribed
	 * @throws Exception if character is not subscribed
	 */
	public void unsubscribeCharacter(Character character) throws Exception
	{
		if(characters.contains(character))
		{
			characters.remove(character);
		}
		else
		{
			throw new Exception("Character is not subscribed to receive lineofsight events.");
		}
		for(Character otherCharacter : characters)
		{
			otherCharacter.characterNoLongerSeen(character);
		}
	}
	
	/**
	 * Check each character's line of sight
	 */
	public void checkLineOfSight()
	{
		// for each character
		for(Character character : characters)
		{
			// check against every other character
			for(Character otherCharacter : characters)
			{
				// if the character can see the other character
				if(character.getLineOfSight().contains(otherCharacter.getX(), otherCharacter.getY()))
				{
					character.characterSeen(otherCharacter);
				}
				// else it cannot see the other character
				else
				{
					character.characterNoLongerSeen(otherCharacter);
				}
			}
		}
	}

}
