/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package menu;

import game.GameSaver;
import game.QuestMain;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Display's a visual representation of the game's collection of save files
 * @author Eyleen
 */
public class DataTile {
	private final String UNDEF = "assets/data/level_icons/undef.png";
	private final String UNDEF_SELECTED = "assets/data/level_icons/undef-selected.png";
	private final String UNDEF_LOCKED = "assets/data/level_icons/undef-locked.png";
	private final String PREFIX = "assets/data/level_icons/level";
		
	private final String IMAGE;
	private final String SELECTED;
	private final String LOCKED;
	private final String OVERLAY;
	
	//tile sizes [screen coors]
	private final float TILE_SIZE_X = 0.15f;
	private final float TILE_SIZE_Y = 0.1f;
	
	//tile position
	private final float X;
	private final float Y;
	
	//save slot data
	private int index;
	
	//texture regions
	private Texture image;
	private Texture selected;
	private Texture locked;
	private Texture overlay;
	
	private TextureRegion region;
	private TextureRegion overlayRegion; 
	
	private GameSaver saver;

	public DataTile(float originX, float originY, int num){
		X = originX;
		Y = originY;
		index = num;
		
		String img = PREFIX + (index + 1) + "-icon.png";
		if(Gdx.files.internal(img).exists())
			IMAGE = img;
		else
			IMAGE = UNDEF;
		
		img = PREFIX + (index + 1) + "-selected.png";
		if(Gdx.files.internal(img).exists())
			SELECTED = img;
		else
			SELECTED = UNDEF_SELECTED;
		
		img = PREFIX + (index + 1) + "-locked.png";
		if(Gdx.files.internal(img).exists())
			LOCKED = img;
		else
			LOCKED = UNDEF_LOCKED;
		
		OVERLAY = PREFIX + (index + 1) + ".png";
		
		image = new Texture(Gdx.files.internal(IMAGE));
		image.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		selected = new Texture(Gdx.files.internal(SELECTED));
		selected.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		locked = new Texture(Gdx.files.internal(LOCKED));
		locked.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		overlay = new Texture(Gdx.files.internal(OVERLAY));
		overlay.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		region = new TextureRegion(locked, 0, 0, Size.QUARTERSCREEN,
				Size.PORTRAIT);
		overlayRegion = new TextureRegion(overlay, 0, 0, Size.QUARTERSCREEN,
				Size.PORTRAIT);
		
		saver = GameSaver.getInstance();
	}
	
	public void draw(SpriteBatch spriteBatch, int select) {
		if(saver.getFarthestLevel() < index || index >= QuestMain.numLevels){
			region.setRegion(locked);
		}else if(select == index){
			region.setRegion(selected);
		}else{
			region.setRegion(image);
		}
		
		spriteBatch.draw(region, X, Y, TILE_SIZE_X, TILE_SIZE_Y);
		spriteBatch.draw(overlayRegion, X, Y, TILE_SIZE_X, TILE_SIZE_Y);
	}

	public int select(){
		return index;
	}

	public boolean inRange(float x, float y) {		
		return Input.inRange(x, y, X, Y, TILE_SIZE_X, TILE_SIZE_Y);
	}
	
	public boolean isLocked(){
		return saver.getFarthestLevel() < index;
	}
}
