/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package menu;

import com.badlogic.gdx.graphics.g2d.SpriteBatch;

/**
 * This class displays the game's nine save slots in a 3x3 grid
 * @author Eyleen
 * @version Jan 04 2014
 */
public class DataTileGroup {
	//positioning variables
	private final float ORIGIN_X;
	private final float ORIGIN_Y;
	private final float OFFSET_X = 0.33f;
	private final float OFFSET_Y = 0.15f;
	private final int ROWS;
	private final int COLUMNS;
	
	private DataTile[][] data;
	private DataTile[][] data2;
	private int page;
	
	/**
	 * Constructor
	 * @param originX x-coordinate of the grid's lower left corner
	 * @param originY y-coordinate of the grid's lower left corner
	 * @param rows number of rows in the grid
	 * @param columns number of columns in the grid
	 */
	public DataTileGroup(float originX, float originY, int rows, int columns) {
		ORIGIN_X = originX;
		ORIGIN_Y = originY;
		ROWS = rows;
		COLUMNS = columns;
		
		data = new DataTile[COLUMNS][ROWS];
		data2 = new DataTile[COLUMNS][ROWS];
		page = 0;
		
		data[0][0] = new DataTile(ORIGIN_X, ORIGIN_Y, 0);
		data[0][1] = new DataTile(ORIGIN_X + OFFSET_X, ORIGIN_Y, 1);
		data[0][2] = new DataTile(ORIGIN_X + (2 * OFFSET_X), ORIGIN_Y, 2);
		data[1][0] = new DataTile(ORIGIN_X, ORIGIN_Y - OFFSET_Y, 3);
		data[1][1] = new DataTile(ORIGIN_X + OFFSET_X, ORIGIN_Y - OFFSET_Y, 4);
		data[1][2] = new DataTile(ORIGIN_X + (2 * OFFSET_X), ORIGIN_Y - OFFSET_Y, 5);
		data[2][0] = new DataTile(ORIGIN_X, ORIGIN_Y - (2 * OFFSET_Y), 6);
		data[2][1] = new DataTile(ORIGIN_X + OFFSET_X, ORIGIN_Y - (2 * OFFSET_Y), 7);
		data[2][2] = new DataTile(ORIGIN_X + (2 * OFFSET_X), ORIGIN_Y - (2 * OFFSET_Y), 8);
		
		data2[0][0] = new DataTile(ORIGIN_X, ORIGIN_Y, 9);
		data2[0][1] = new DataTile(ORIGIN_X + OFFSET_X, ORIGIN_Y, 10);
		data2[0][2] = new DataTile(ORIGIN_X + (2 * OFFSET_X), ORIGIN_Y, 11);
		data2[1][0] = new DataTile(ORIGIN_X, ORIGIN_Y - OFFSET_Y, 12);
		data2[1][1] = new DataTile(ORIGIN_X + OFFSET_X, ORIGIN_Y - OFFSET_Y, 13);
		data2[1][2] = new DataTile(ORIGIN_X + (2 * OFFSET_X), ORIGIN_Y - OFFSET_Y, 14);
		data2[2][0] = new DataTile(ORIGIN_X, ORIGIN_Y - (2 * OFFSET_Y), 15);
		data2[2][1] = new DataTile(ORIGIN_X + OFFSET_X, ORIGIN_Y - (2 * OFFSET_Y), 16);
		data2[2][2] = new DataTile(ORIGIN_X + (2 * OFFSET_X), ORIGIN_Y - (2 * OFFSET_Y), 17);
		
	}

	public void draw(SpriteBatch spriteBatch, int selected) {
		for(int i = 0; i < COLUMNS; i++){
			for(int j = 0; j < ROWS; j++){
				if(page == 0)
					data[i][j].draw(spriteBatch, selected);
				else
					data2[i][j].draw(spriteBatch, selected);
			}
		}
	}

	public int getColumns() {
		return COLUMNS;
	}

	public int getRows() {
		return ROWS;
	}

	public DataTile get(int i, int j) {
		if(i < 0 || i >= COLUMNS || j < 0 || j >= ROWS){
			return null;
		}
		if(page == 0)
			return data[i][j];
		else if(page == 1)
			return data2[i][j];
		
		return null;
	}

	public boolean inRange(float x, float y, int i, int j){
		return data[i][j].inRange(x, y);
	}
	
	public void nextPage(){
		if(page == 0){
			page = 1;
		}
	}
	
	public void lastPage(){
		if(page == 1){
			page = 0;
		}
	}
	
	public int getPage(){
		return page;
	}
}
