package menu;

import game.QuestMain;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.Input.Buttons;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

public class EndGameScreen extends MenuScreen implements Screen {
	private QuestMain game;
	
	private final String BG = "assets/data/menu/black_bg.png";
	private final String END_GAME_BG = "assets/data/menu/end_game_bg.png";
	private final String CREDITS_BG = "assets/data/menu/credits_bg.png";
	private final String NEW_GAME = "assets/data/menu/new_game.png";
	private final String LOAD_GAME = "assets/data/menu/load.png";
	private final String QUIT_GAME = "assets/data/menu/quit.png";
	
	private final float BG_SIZE_X = 1.1f;
	private final float BG_SIZE_Y = 1.0f;
	private final float BUTTON_SIZE_X = 0.2f;
	private final float BUTTON_SIZE_Y = 0.1f;
	
	private final float BG_X = -0.5f;
	private final float BG_Y = -0.5f;
	private final float BUTTON_X = 0.3f;
	private final float NEW_GAME_Y = 0.3f;
	private final float LOAD_GAME_Y = 0.0f;
	private final float QUIT_GAME_Y = -0.3f;
	
	private Texture blackBg;
	private Texture endGameBg;
	private Texture creditsBg;
	private Texture newGame;
	private Texture loadGame;
	private Texture quitGame;
	
	private TextureRegion blackBackground;
	private TextureRegion background;
	private TextureRegion creditsBackground;
	private TextureRegion newGameRegion;
	private TextureRegion loadGameRegion;
	private TextureRegion quitGameRegion;
	
	private LoadMenuScreen loadScreen;
	private MainMenuScreen menuScreen;
	
	private boolean credits;
	private int timer;

	public EndGameScreen(QuestMain g) throws Exception {
		super();
		
		blackBg = new Texture(Gdx.files.internal(BG));
		blackBg.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		endGameBg = new Texture(Gdx.files.internal(END_GAME_BG));
		endGameBg.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		creditsBg = new Texture (Gdx.files.internal(CREDITS_BG));
		creditsBg.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		newGame = new Texture(Gdx.files.internal(NEW_GAME));
		newGame.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		loadGame = new Texture(Gdx.files.internal(LOAD_GAME));
		loadGame.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		quitGame = new Texture(Gdx.files.internal(QUIT_GAME));
		quitGame.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		blackBackground = new TextureRegion(blackBg, 0, 0, Size.FULLSCREEN,
				Size.FULLSCREEN);
		background = new TextureRegion(endGameBg, 0, 0, Size.HALFSCREEN,
				Size.HALFSCREEN);
		creditsBackground = new TextureRegion(creditsBg, 0, 0, Size.HALFSCREEN,
				Size.HALFSCREEN); 
		newGameRegion = new TextureRegion(newGame, 0, 0, Size.QUARTERSCREEN,
				Size.ICON);
		loadGameRegion = new TextureRegion(loadGame, 0, 0, Size.QUARTERSCREEN,
				Size.ICON);
		quitGameRegion = new TextureRegion(quitGame, 0, 0, Size.QUARTERSCREEN,
				Size.ICON);
		
		credits = false;
		active = false;
		game = g;
		loadScreen = LoadMenuScreen.getInstance();
		menuScreen = MainMenuScreen.getInstance();
		
		timer = 300;
	}
	
	@Override
	public boolean keyUp(int keycode) {
		if(!credits && timer == 0){
			credits = true;
			return true;
		}
		return false;
	}

	@Override
	public boolean keyTyped(char character) {
		if(!credits && timer == 0){
			credits = true;
			return true;
		}
		return false;
	}

	@Override
	public boolean touchUp(int screenX, int screenY, int pointer, int button){
		if(!credits && timer == 0){
			credits = true;
			return true;
		}
		
		if(button == Buttons.LEFT){
		
			float x = Input.convertScreenCoorsX(screenX);
			float y = Input.convertScreenCoorsY(screenY);
		
			if(Input.inRange(x, y, BUTTON_X, NEW_GAME_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y)){
				game.setScreen(0);
				return true;
			}
			if(Input.inRange(x, y, BUTTON_X, LOAD_GAME_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y)){
				loadScreen.activate(MainMenuScreen.getInstance());
				Gdx.input.setInputProcessor(loadScreen);
				return true;
			}
			if(Input.inRange(x, y, BUTTON_X, QUIT_GAME_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y)){
				System.exit(0);
				return true;
			}
		}
		
		return false;
	}
	
	@Override
	public boolean touchDown(int screenX, int screenY, int pointer, int button) {
		return false;
	}

	@Override
	public boolean touchDragged(int screenX, int screenY, int pointer) {
		return false;
	}

	@Override
	public boolean mouseMoved(int screenX, int screenY) {
		return false;
	}

	@Override
	public boolean scrolled(int amount) {
		return false;
	}
	
	@Override
	protected void draw() {
		if(!active)
			return;
		
		if(timer > 0)
			timer--;
		
		spriteBatch.setProjectionMatrix(camera.combined);
		spriteBatch.begin();
		
		spriteBatch.draw(blackBackground, BG_X, BG_Y, BG_SIZE_X, BG_SIZE_Y);
		
		if(!credits){
			spriteBatch.draw(background, BG_X, BG_Y, BG_SIZE_X, BG_SIZE_Y);
		}else{
			spriteBatch.draw(creditsBackground, BG_X, BG_Y, BG_SIZE_X, BG_SIZE_Y);
			spriteBatch.draw(newGameRegion, BUTTON_X, NEW_GAME_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y);
			spriteBatch.draw(loadGameRegion, BUTTON_X, LOAD_GAME_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y);
			spriteBatch.draw(quitGameRegion, BUTTON_X, QUIT_GAME_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y);
		}
		loadScreen.draw(spriteBatch);
		menuScreen.draw(spriteBatch);
		
		spriteBatch.end();
	}
	
	@Override
	protected void draw(SpriteBatch spriteBatch) {}

	@Override
	public void render(float delta) {
		clearScreen();
		draw();
	}

	@Override
	public void resize(int width, int height) {}

	@Override
	public void show() {}

	@Override
	public void hide() {}

	@Override
	public void pause() {}

	@Override
	public void resume() {}

	@Override
	public void dispose() {
		spriteBatch.dispose();
	}
}
