/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package menu;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.InputProcessor;

import game.GameSaver;
import hud.HUD;

/**
 * This screen handles the loading of save data
 * Accessible from the main menu
 * A singleton 
 * @author Eyleen
 * @version Jan 03 2014
 *
 */
public class LoadMenuScreen extends SubMenuScreen{
	private static LoadMenuScreen instance = null;
	
	private InputProcessor lastMenu;
		
	private LoadMenuScreen() throws Exception {
		super("assets/data/menu/level_select_banner.png", "assets/data/menu/load.png");
	}
	
	public static LoadMenuScreen makeNewInstance() throws Exception{
		instance = new LoadMenuScreen();
		return instance;
	}
	
	public static LoadMenuScreen getInstance(){
		return instance;
	}

	@Override
	protected void buttonPressed() {
		loadGame();
	}

	public void loadGame(){
		try {
			ProgressJournal.loadJournal(selected);
			GameSaver.getInstance().loadGame(selected);
			Gdx.input.setInputProcessor(HUD.getMultiplexer());
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Override
	protected void back(){
		deactivate();
		Gdx.input.setInputProcessor(lastMenu);
	}

	@Override
	protected boolean select(float x, float y) {
		for(int i = 0; i < data.getRows(); i++){
			for(int j = 0; j < data.getColumns(); j++){
				if(data.inRange(x, y, i, j)
						&& !data.get(i, j).isLocked()){
					selected = data.get(i, j).select();
					return true;
				}
			}
		}
		return false;
	}
	
	protected void activate(MenuScreen menu){
		active = true;
		lastMenu = menu;
	}
}
