/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package menu;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.InputProcessor;
import com.badlogic.gdx.graphics.GL10;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;

/**
 * The abstract super class to the game's menu screens
 * @author Eyleen
 * @version Jan 4 2014
 */
public abstract class MenuScreen implements InputProcessor {
	protected final int BACKGROUND_WIDTH = 1000;
	protected final int BACKGROUND_HEIGHT = 1000;
	
	//other variables needed by the Screen
	protected OrthographicCamera camera;
	protected SpriteBatch spriteBatch;
	
	//variable for certain overlay menus
	//overlay or menu will be displayed if true
	protected boolean active;
	
	/**
	 * Constructor
	 * @throws Exception
	 */
	protected MenuScreen() throws Exception{		
		//screen setup
		Gdx.graphics.setDisplayMode(BACKGROUND_WIDTH, BACKGROUND_HEIGHT, false);
		float w = Gdx.graphics.getWidth();
		float h = Gdx.graphics.getHeight();

		spriteBatch = new SpriteBatch(); 
		camera = new OrthographicCamera(1, h/w);
		active = false;
	}
	
	/**
	 * Clear the screen
	 */
	protected void clearScreen()
	{
		Gdx.gl.glClearColor(1, 1, 1, 1);
		Gdx.gl.glClear(GL10.GL_COLOR_BUFFER_BIT);
	}
	
	/**
	 * Activate [make visible and take input from] the MenuScreen
	 * Use optional
	 */
	public void activate(){
		active = true;
	}

	/**
	 * Deactivate [make invisible] the MenuScreen
	 * Use optional
	 */
	protected void deactivate(){
		active = false;
	}
	
	/**
	 * Draw the objects on the screen using an existing spriteBatch
	 */
	protected abstract void draw(SpriteBatch spriteBatch);
	
	/**
	 * Draw objects to the screen
	 */
	protected abstract void draw();
	
	@Override
	public boolean keyDown(int keycode){
		return false;
	}
	
	@Override
	public boolean keyUp(int keycode) {
		return false;
	}

	@Override
	public boolean keyTyped(char character) {
		return false;
	}

	@Override
	public abstract boolean touchUp(int screenX, int screenY, int pointer, int button);
	
	@Override
	public boolean touchDown(int screenX, int screenY, int pointer, int button) {
		return false;
	}

	@Override
	public boolean touchDragged(int screenX, int screenY, int pointer) {
		return false;
	}

	@Override
	public boolean mouseMoved(int screenX, int screenY) {
		return false;
	}

	@Override
	public boolean scrolled(int amount) {
		return false;
	}
}
