/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package menu;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Buttons;
import com.badlogic.gdx.audio.Sound;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Superclass to the game's confirmation overlays
 * @author Eyleen
 * @version Jan 10 2014
 */
public abstract class Overlay extends MenuScreen{
	//file names
	protected final String BACKGROUND = "assets/data/menu/shaded_bg.png";
	protected final String BOX = "assets/data/menu/box.png";
	protected final String YES = "assets/data/menu/yes.png";
	protected final String NO = "assets/data/menu/no.png";
	protected final String MESSAGE;
	
	//initialize the audio file
	Sound selectSound = Gdx.audio.newSound(Gdx.files.internal("assets/data/sound/select.wav"));

	
	//image positions
	protected final float BOX_X = -0.175f;
	protected final float BOX_Y = -0.12f;
	protected final float YES_X = -0.13f;
	protected final float YES_Y = -0.09f;
	protected final float NO_X = 0.1f;
	protected final float NO_Y = -0.09f;
	protected final float MESSAGE_X = -0.15f;
	protected final float MESSAGE_Y = 0.0f;
	
	//image sizes [screen space]
	protected final float BOX_SIZE_X = 0.4f;
	protected final float BOX_SIZE_Y = 0.25f;
	protected final float BUTTON_SIZE_X = 0.08f;
	protected final float BUTTON_SIZE_Y = 0.08f;
	protected final float MESSAGE_SIZE_X = 0.35f;
	protected final float MESSAGE_SIZE_Y = 0.1f;
	
	//texture regions
	protected TextureRegion background;
	protected TextureRegion box;
	protected TextureRegion yes;
	protected TextureRegion no;
	protected TextureRegion message;
	
	/**
	 * Super-class Constructor
	 * @param m the message displayed by the overlay
	 * @throws Exception
	 */
	protected Overlay(String fileName) throws Exception{		
		MESSAGE = fileName;
		
		Texture backgroundTexture = new Texture(Gdx.files.internal(BACKGROUND));
		backgroundTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		Texture boxTexture = new Texture(Gdx.files.internal(BOX));
		boxTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		Texture yesTexture = new Texture(Gdx.files.internal(YES));
		yesTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		Texture noTexture = new Texture(Gdx.files.internal(NO));
		noTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		Texture messageTexture = new Texture(Gdx.files.internal(MESSAGE));
		messageTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		background = new TextureRegion(backgroundTexture, 0, 0, Size.FULLSCREEN,
				Size.FULLSCREEN);
		box = new TextureRegion(boxTexture, 0, 0, Size.QUARTERSCREEN,
				Size.ICON);
		yes = new TextureRegion(yesTexture, 0, 0, Size.ICON, Size.ICON);
		no = new TextureRegion(noTexture, 0, 0, Size.ICON, Size.ICON);
		message = new TextureRegion(messageTexture, 0, 0, Size.QUARTERSCREEN,
				Size.ICON);
	}

	@Override
	protected void draw(){}
	
	@Override
	protected void draw(SpriteBatch spriteBatch) {
		if(!active){
			return;
		}
		
		spriteBatch.draw(background, -0.5f, -0.5f, 1.0f, 1.0f);
		
		spriteBatch.draw(box, BOX_X, BOX_Y, BOX_SIZE_X, BOX_SIZE_Y);
		spriteBatch.draw(yes, YES_X, YES_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y);
		spriteBatch.draw(no, NO_X, NO_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y);
		spriteBatch.draw(message, MESSAGE_X, MESSAGE_Y, MESSAGE_SIZE_X,
				MESSAGE_SIZE_Y);
	}

	@Override
	public boolean touchUp(int screenX, int screenY, int pointer, int button) {
		//left mouse button clicked
		if(button == Buttons.LEFT){
			float x = Input.convertScreenCoorsX(screenX);
			float y = Input.convertScreenCoorsY(screenY);
			
			//yes
			if(Input.inRange(x, y, YES_X, YES_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y)){
				//play sound
				selectSound.play(1.0f);
				
				confirmed();
				return true;
			}//no
			if(Input.inRange(x, y, NO_X, NO_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y)){
				//play sound
				selectSound.play(1.0f);
				
				rejected();
				return true;
			}
		}
		return false;
	}
	
	/**
	 * Proposed active accepted
	 * @param 
	 * @throws Exception 
	 */
	public abstract void confirmed();
	
	/**
	 * Proposed action rejected
	 */
	public abstract void rejected();
}
