package menu;

import java.util.ArrayList;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * A single page of a progress journal
 * Stores all versions of that page
 * @author Eyleen
 */
public class Page{	
	private final float X;
	private final float Y;
	private final float SIZE_X = 0.5f;
	private final float SIZE_Y = 0.4f;
	
	private ArrayList<Texture> versionTexture;
	private ArrayList<String> triggers;
	private ArrayList<String> characters;
	private ArrayList<String> npcs;
	private ArrayList<Integer> indexes;
	private ArrayList<Integer> levels;
	private TextureRegion region;
	
	private int index = 0;
	
	/**
	 * 
	 * @param x screen coor
	 * @param y screen coor
	 * @param list versions of this page
	 */
	public Page(float x, float y, String file) {
		X = x;
		Y = y;
		versionTexture = new ArrayList<Texture>();
		triggers = new ArrayList<String>();
		characters = new ArrayList<String>();
		npcs = new ArrayList<String>();
		indexes = new ArrayList<Integer>();
		levels = new ArrayList<Integer>();
		
		getPageInfo(file);
		
		region = new TextureRegion(versionTexture.get(index));
	}
	
	public void getPageInfo(String fileName){
		FileHandle file = Gdx.files.internal(fileName);
		String fileText = file.readString();
		String[] fileTokens = fileText.split(" |\n");
		int i = 0;

		// loop through the tokens
		while (!fileTokens[i].equals("EOF"))
		{
			triggers.add(fileTokens[i]);
			i++;
			
			versionTexture.add(new Texture(
					Gdx.files.internal(fileTokens[i])));
			i++;
			characters.add(fileTokens[i]);
			i++;
			
			npcs.add(fileTokens[i]);
			i++;
			
			indexes.add(Integer.parseInt(fileTokens[i]));
			i++;
			
			levels.add(Integer.parseInt(fileTokens[i].substring(0,
					fileTokens[i].length() - 1)));
			i++;
		}
	}

	public void onDialogue(String character, String npc, int i){
		if(triggers.get(index).equals("on_dialogue")
				&& characters.get(index).equals(character)
				&& npcs.get(index).equals(npc)
				&& indexes.get(index) == i){
			index++;
		}
		
		if(index == triggers.size() - 1)
			ProgressJournal.advanceJournal();
	}
	
	public void onExit(int i) {
		if(triggers.get(index).equals("on_exit")
				&& levels.get(index).equals(i)){
			index++;
		}
		if(index == triggers.size() - 1)
			ProgressJournal.advanceJournal();
	}
	
	public void onEnemyDeath(int i) {
		if(triggers.get(index).equals("on_enemyDeath")
				&& levels.get(index).equals(i)){
			index++;			
		}
		if(index == triggers.size() - 1)
			ProgressJournal.advanceJournal();
	}
	
	public boolean finished(){
		return index == triggers.size() - 1;
	}

	public void draw(SpriteBatch spriteBatch) {
		region.setRegion(versionTexture.get(index));
		
		spriteBatch.draw(region, X, Y, SIZE_X, SIZE_Y);
	}

	public void end(){
		index = triggers.size() - 1;
	}
}
