package menu;

import java.util.ArrayList;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Handles the displaying of the progress journal and its control and
 * @author Eyleen
 */
public class ProgressJournal{
	private static ProgressJournal instance = null;
	
	private final String NEXT = "assets/data/menu/next.png";
	private final String NEXT_INACTIVE = "assets/data/menu/next-inactive.png";
	private final String PREVIOUS = "assets/data/menu/previous.png";
	private final String PREVIOUS_INACTIVE = "assets/data/menu/previous-inactive.png";
	
	private final float X = -0.24f;
	private final float Y = -0.075f;
	private final float NEXT_OFFSET_X = 0.55f;
	private final float PREVIOUS_OFFSET_X = -0.15f;
	private final float OFFSET_Y = 0.15f;
	private final float BUTTON_SIZE = 0.1f;
	
	private Texture next;
	private Texture nextInactive;
	private Texture previous;
	private Texture previousInactive;
	private TextureRegion nextRegion;
	private TextureRegion previousRegion;
	
	private static ArrayList<Page> pages;
	private static int maxIndex = 0;
	private static int displayIndex = 0;
	
	private ProgressJournal(){
		pages = new ArrayList<Page>();
		addPages("assets/data/journal/journal.txt");
		
		next = new Texture(Gdx.files.internal(NEXT));
		nextInactive = new Texture(Gdx.files.internal(NEXT_INACTIVE));
		previous = new Texture(Gdx.files.internal(PREVIOUS));
		previousInactive = new Texture(Gdx.files.internal(PREVIOUS_INACTIVE));
		
		nextRegion = new TextureRegion(next, 0, 0, Size.PORTRAIT, Size.PORTRAIT);
		previousRegion = new TextureRegion(previousInactive, 0, 0, Size.PORTRAIT, Size.PORTRAIT);
	}
	
	public static ProgressJournal makeNewInstance(){
		if(instance != null)
			return instance;
		instance = new ProgressJournal();
		return instance;
	}
	
	public ProgressJournal getInstance(){
		return instance;
	}
	
	protected void addPages(String fileName){
		FileHandle file = Gdx.files.internal(fileName);
		String fileText = file.readString();
		String[] fileTokens = fileText.split(" |\n");
		int i = 0;

		// loop through the tokens
		while (!fileTokens[i].equals("EOF"))
		{
			String page = fileTokens[i].substring(0, fileTokens[i].length() - 1);
			i++;
			
			pages.add(new Page(X, Y, page));
		}
	}
	
	public static void loadJournal(int level){
		level -= 1;
		
		for(int i = 0; i <= (level < pages.size() - 1 ? level : pages.size() - 1); i++){
			pages.get(i).end();
		}
		
		if(level < 0)
			maxIndex = 0;
		else if(level >= pages.size() - 1){
			maxIndex = pages.size();
			pages.get(maxIndex).end();
		}
		else
			maxIndex = level + 1;
		
		displayIndex = maxIndex;
	}
	
	public static void onDialogue(String character, String npc, int i) {
		if(i < 0)
			return;
		
		pages.get(maxIndex).onDialogue(character, npc, i);
	}
	
	public static void onExit(int i){
		if(i < 0)
			return;
		
		pages.get(maxIndex).onExit(i);
	}

	public static void onEnemyDeath(int i) {
		if(i < 0)
			return;
		
		pages.get(maxIndex).onEnemyDeath(i);
	}

	public void draw(SpriteBatch spriteBatch) {
		if(displayIndex == 0){
			previousRegion.setRegion(previousInactive);
		}else{
			previousRegion.setRegion(previous);
		}
		
		if(displayIndex == maxIndex || displayIndex == pages.size() - 1){
			nextRegion.setRegion(nextInactive);
		}else{
			nextRegion.setRegion(next);
		}		
		pages.get(displayIndex).draw(spriteBatch);
		spriteBatch.draw(nextRegion, X + NEXT_OFFSET_X, Y + OFFSET_Y, BUTTON_SIZE, BUTTON_SIZE);
		spriteBatch.draw(previousRegion, X + PREVIOUS_OFFSET_X, Y + OFFSET_Y, BUTTON_SIZE, BUTTON_SIZE);
	}

	public boolean inRange(float x, float y) {
		if(x >= X + NEXT_OFFSET_X && x <= X + NEXT_OFFSET_X + BUTTON_SIZE
				&& y >= Y + OFFSET_Y && y <= Y + OFFSET_Y + BUTTON_SIZE 
				&& displayIndex < maxIndex && displayIndex < pages.size() - 1){
			displayIndex++;
			return true;
		}
		if(x >= X + PREVIOUS_OFFSET_X && x <= X + PREVIOUS_OFFSET_X + BUTTON_SIZE
				&& y >= Y + OFFSET_Y && y <= Y + OFFSET_Y + BUTTON_SIZE 
				&& displayIndex > 0){
			displayIndex--;
			return true;
		}
		
		return false;
	}

	public static void advanceJournal() {
		maxIndex++;
	}
}
