/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package menu;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Buttons;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

/**
 * Abstract super class to the load and save menus
 * @author Eyleen
 * @version Jan 05 2014
 */
public abstract class SubMenuScreen extends MenuScreen {
	//common image file paths
	protected final String BACKGROUND = "assets/data/menu/level_select_bg.png";
	protected final String BACK = "assets/data/menu/back.png";
	protected final String NEXT = "assets/data/menu/next.png";
	protected final String NEXT_INACTIVE = "assets/data/menu/next-inactive.png";
	protected final String PREVIOUS = "assets/data/menu/previous.png";
	protected final String PREVIOUS_INACTIVE = "assets/data/menu/previous-inactive.png";
	
	protected final String BANNER;
	//this will either be a load button or a save button
	protected final String BUTTON;
	
	//image size [screen coors]
	protected final float BANNER_SIZE_X = 0.6f;
	protected final float BANNER_SIZE_Y = 0.3f;
	protected final float BUTTON_SIZE_X = 0.25f;
	protected final float BUTTON_SIZE_Y = 0.1f;
	protected final float NAV_SIZE_X = 0.1f;
	protected final float NAV_SIZE_Y = 0.1f;
	
	//image positions
	protected final float BANNER_X = -0.3f;
	protected final float BANNER_Y = 0.15f;
	protected final float BACK_X = -0.44f;
	protected final float BACK_Y = -0.45f;
	protected final float BUTTON_X = -0.11f;
	protected final float BUTTON_Y = -0.45f;
	protected final float TILE_ORIGIN_X = -0.4f;
	protected final float TILE_ORIGIN_Y = 0.0f;
	protected final float NEXT_X = 0.4f;
	protected final float PREVIOUS_X = -0.49f;
	protected final float NAV_Y = -0.15f;
	
	protected Texture next;
	protected Texture nextInactive;
	protected Texture previous;
	protected Texture previousInactive;
	
	protected TextureRegion nextRegion;
	protected TextureRegion previousRegion;
	
	//texture regions
	protected TextureRegion background;
	protected TextureRegion banner;
	protected TextureRegion back;
	protected TextureRegion button;
	
	//overlays
	protected LoadOverlay loadOverlay;
	
	protected DataTileGroup data;
	protected int selected;
	
	/**
	 * Constructor
	 * @param bannerFileName
	 * @param buttonFileName
	 * @throws Exception
	 */
	protected SubMenuScreen(String bannerFileName, String buttonFileName)
			throws Exception{
		super();
		
		BANNER = bannerFileName;
		BUTTON = buttonFileName;
		
		Texture backgroundTexture = new Texture(Gdx.files.internal(BACKGROUND));
		backgroundTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		Texture bannerTexture = new Texture(Gdx.files.internal(BANNER));
		bannerTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		Texture backTexture = new Texture(Gdx.files.internal(BACK));
		backTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		Texture buttonTexture = new Texture(Gdx.files.internal(BUTTON));
		buttonTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		next = new Texture(Gdx.files.internal(NEXT));
		next.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		nextInactive = new Texture(Gdx.files.internal(NEXT_INACTIVE));
		nextInactive.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		previous = new Texture(Gdx.files.internal(PREVIOUS));
		previous.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		previousInactive = new Texture(Gdx.files.internal(PREVIOUS_INACTIVE));
		previousInactive.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		background = new TextureRegion(backgroundTexture, 0, 0, Size.FULLSCREEN,
				Size.FULLSCREEN);
		banner = new TextureRegion(bannerTexture, 0, 0, Size.HALFSCREEN,
				Size.QUARTERSCREEN);
		back = new TextureRegion(backTexture, 0, 0, Size.QUARTERSCREEN,
				Size.ICON);
		button = new TextureRegion(buttonTexture, 0, 0, Size.QUARTERSCREEN,
				Size.ICON);
		nextRegion = new TextureRegion(next, 0, 0, Size.PORTRAIT, Size.PORTRAIT);
		previousRegion = new TextureRegion(previousInactive, 0, 0, Size.PORTRAIT,
				Size.PORTRAIT);
		
		data = new DataTileGroup(TILE_ORIGIN_X, TILE_ORIGIN_Y, 3, 3);
		selected = -1;

		loadOverlay = new LoadOverlay();
		
		if(data.getPage() == 0){
			nextRegion.setRegion(next);
			previousRegion.setRegion(previousInactive);
		}else{
			nextRegion.setRegion(nextInactive);
			previousRegion.setRegion(previous);
		}
	}
	
	public void draw(){}

	public void draw(SpriteBatch spriteBatch){
		if(!active){
			return;
		}
		
		if(data.getPage() == 0){
			nextRegion.setRegion(next);
			previousRegion.setRegion(previousInactive);
		}else{
			nextRegion.setRegion(nextInactive);
			previousRegion.setRegion(previous);
		}
		
		//draw menu components
		spriteBatch.draw(background, -0.5f, -0.5f, 1.0f, 1.0f);
		spriteBatch.draw(banner, BANNER_X, BANNER_Y, BANNER_SIZE_X,
				BANNER_SIZE_Y);
		spriteBatch.draw(back, BACK_X, BACK_Y, BUTTON_SIZE_X, BUTTON_SIZE_Y);
		spriteBatch.draw(button, BUTTON_X, BUTTON_Y, BUTTON_SIZE_X,
				BUTTON_SIZE_Y);
		spriteBatch.draw(nextRegion, NEXT_X, NAV_Y, NAV_SIZE_X, NAV_SIZE_Y);
		spriteBatch.draw(previousRegion, PREVIOUS_X, NAV_Y, NAV_SIZE_X, NAV_SIZE_Y);
		
		//draw data tiles
		data.draw(spriteBatch, selected);
		
		//draw overlays
		loadOverlay.draw(spriteBatch);
	}

	protected abstract void buttonPressed();
	
	protected abstract void back();
	
	@Override
	public boolean touchUp(int screenX, int screenY, int pointer, int button){
		//left mouse button clicked
		if(button == Buttons.LEFT){
			//convert screen coordinates
			float x = Input.convertScreenCoorsX(screenX);
			float y = Input.convertScreenCoorsY(screenY);
				
			if(Input.inRange(x, y, BACK_X, BACK_Y, BUTTON_SIZE_X,
					BUTTON_SIZE_Y)){
				//back
				back();
				return true;
			}
			if(Input.inRange(x, y, BUTTON_X, BUTTON_Y, BUTTON_SIZE_X,
					BUTTON_SIZE_Y) && selected >= 0){
				//[load or save] button
				buttonPressed();
				return true;
			}
			if(Input.inRange(x, y, NEXT_X, NAV_Y, NAV_SIZE_X, NAV_SIZE_Y)
					&& data.getPage() == 0){
				data.nextPage();
				return true;
			}
			if(Input.inRange(x, y, PREVIOUS_X, NAV_Y, NAV_SIZE_X, NAV_SIZE_Y)
					&& data.getPage() == 1){
				data.lastPage();
				return true;
			}
			
			return select(x, y);
		}
		return false;
	}
	
	protected abstract boolean select(float x, float y);
}
