/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package pathfinding;


/**
 * A node in a graph, to be used for pathfinding
 * @author jordan
 * @version Jan 22 2014
 */
public class GraphNode {
	
	// screen location
	private float x;
	private float y;
	
	// graph location
	private final int graphX;
	private final int graphY;
	
	// whether the node is occupied or not
	private boolean occupied;
	
	/**
	 * Constructor
	 * @param x the x position on the screen
	 * @param y the y position on the screen
	 */
	public GraphNode(float x, float y, int graphX, int graphY, boolean occupied)
	{
		this.x = x;
		this.y = y;
		
		this.graphX = graphX;
		this.graphY = graphY;
		
		this.occupied = occupied;
	}
	
	/**
	 * Get the node's x position on the screen
	 * @return the x position
	 */
	public float getX()
	{
		return x;
	}
	
	/**
	 * Get the node's y position on the screen
	 * @return the y position
	 */
	public float getY()
	{
		return y;
	}
	
	/**
	 * Get the node's x position in the graph
	 * @return the x position in the graph
	 */
	public int getGraphX()
	{
		return graphX;
	}
	
	/**
	 * Get the node's y position in the graph
	 * @return the y position in the graph
	 */
	public int getGraphY()
	{
		return graphY;
	}
	
	/**
	 * Check if the node is occupied by an object
	 * (i.e. the object overlaps the node's location)
	 * @return true if occupied, false otherwise
	 */
	public boolean isOccupied()
	{
		return occupied;
	}
	
	/**
	 * Set whether the node is occupied or not
	 * @param isOccupied true to make the node occupied, false to make it unoccupied
	 */
	public void setOccupied(boolean isOccupied)
	{
		occupied = isOccupied;
	}
	
}
