/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package pathfinding;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;

import strategy.GoalManager;
import game.GameUtility;
import game.QuestMain;
import gameobject.character.Character;
import gameobject.GameObject;

/**
 * A class for using A* pathfinding
 * @author jordan
 * @version Jan 26 2014
 */
public class PathFinder {

	// character that owns this pathfinder
	private Character character;

	/**
	 * Constructor
	 * @param character the character that owns this pathfinder instance
	 */
	public PathFinder(Character character)
	{
		this.character = character;
	}
	
	/**
	 * Get the node to seek to that will lead to the target
	 * @param target the target object
	 * @return
	 */
	public GraphNode getCurrentNode(GameObject target)
	{
		return getNode(target.getX(), target.getY());
	}

	/**
	 * Get the node to seek to that will lead to the destination
	 * @param destination the destination node
	 * @return
	 */
	public GraphNode getCurrentNode(GraphNode destination)
	{
		return getNode(destination.getX(), destination.getY());
	}

	/**
	 * Get the best node to lead to the given point
	 * @param x the x coordinate of the destination
	 * @param y the y coordinate of the destination
	 * @return
	 */
	private GraphNode getNode(float x, float y)
	{
		// get the list of connected nodes to the occupied node
		Graph graph = QuestMain.getCurrentScreen().getGraph();
		ArrayList<GraphNode> connectedNodes = graph.getConnectedNodes(character);

		// compare to find the best node
		if(!connectedNodes.isEmpty())
		{
			GraphNode bestNode = connectedNodes.get(0);
			for(GraphNode node : connectedNodes)
			{
				float nodeDist = GameUtility.getStraightLineDistance(node.getX(),  node.getY(),
						x, y);
				float bestDist = GameUtility.getStraightLineDistance(bestNode.getX(), bestNode.getY(),
						x, y);

				// the node is better if it has a shorter distance to the target
				if(nodeDist < bestDist)
				{
					bestNode = node;
				}
			}
			// store and return the node
			return bestNode;
		}
		return graph.getNearestNode(character.getCenterX(), character.getCenterY());
	}
}
