/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy;

import pathfinding.GraphNode;
import gameobject.GameObject;
import gameobject.character.Character;

/**
 * This class represents a goal for a character
 * @author jordan
 * @version Feb 2 2014
 */
public class Goal {
	
	private GoalType goalType;
	
	private int priority;
	
	private GameObject target;
	
	private String printableGoal;
	
	/**
	 * Constructor
	 * @param target the target of the goal
	 * @param goalType the type of goal
	 * @param priority the priority of the goal
	 */
	public Goal(GameObject target, GoalType goalType, int priority)
	{
		this.target = target;
		this.goalType = goalType;
		this.priority = priority;
		
		if(goalType == GoalType.ATTACK)
		{
			printableGoal = "Attack " + target.getName();
		}
		else if (goalType == GoalType.AID)
		{
			printableGoal = "Aid " + target.getName();
		}
		else
		{
			printableGoal = "Survive";
		}
	}
	
	/**
	 * Get the type of the goal
	 * @return goalType
	 */
	public GoalType getType()
	{
		return goalType;
	}
	
	/**
	 * Get the target of the goal
	 * @return target
	 */
	public GameObject getTarget()
	{
		return target;
	}
	
	/**
	 * Get the priority of the goal
	 * @return priority
	 */
	public int getPriority()
	{
		return priority;
	}
	
	/**
	 * Set the priority of the goal
	 * @param newPriority the new priority
	 */
	public void setPriority(int newPriority)
	{
		priority = newPriority;
	}
	
	/**
	 * Get the printable goal as a string
	 * @return printableGoal
	 */
	public String getPrintable()
	{
		return printableGoal;
	}

}
