/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy;

import gameobject.character.Character;
import pathfinding.Graph;
import pathfinding.PathFinder;
import strategy.statemachine.StateMachine;

/**
 * This represents a strategy for a particular mode
 * @author jordan
 * @version Feb 2 2014
 */
public abstract class ModeStrategy {

	protected Character character;
	protected Goal goal;

	protected StateMachine stateMachine;

	protected String strategyName;

	/**
	 * Constructor
	 * @param character the character to whom this strategy belongs
	 * @param goal the goal associated with the strategy
	 */
	public ModeStrategy(Character character, Goal goal)
	{
		this.character = character;
		this.goal = goal;
		stateMachine = new StateMachine();
	}

	/**
	 * Update the strategy
	 * @param delta the time since the last update
	 */
	public void update(float delta) {
		stateMachine.update(delta);
	}

	/**
	 * Get the strategy name as a string
	 * @return strategyName
	 */
	public String getStrategyName()
	{
		return strategyName;
	}
	
	/**
	 * Get the state machine
	 * @return stateMachine
	 */
	public StateMachine getStateMachine()
	{
		return stateMachine;
	}

}
