/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy;

import event.AIEvent;
import pathfinding.PathFinder;
import gameobject.character.Character;

/**
 * The strategy for the warrior archetype
 * @author jordan
 * @version Jan 26 2014
 */
public abstract class Strategy {
	
	private Character character;
	
	protected Goal currentGoal;
	
	protected ModeStrategy currentStrategy;
	
	/**
	 * Constructor
	 */
	public Strategy(Character character)
	{
		this.character = character;
		currentGoal = new Goal(null, GoalType.SURVIVE, 0);
	}

	/**
	 * Update the strategy, overridden by subclass
	 * @param delta the time since the last update
	 */
	public void update(float delta) {
		
		// get the current goal
		GoalManager goalManager = character.getGoalManager();
		goalManager.update(delta);
		
		Goal goal = goalManager.getCurrentGoal();
		
		// if the goal has changed
		if(goal != currentGoal)
		{
			// new attack strategy
			if(goal.getType() == GoalType.ATTACK)
			{
				currentStrategy = getAttackStrategy(character, goal);
			}
			// new aid strategy
			else if (goal.getType() == GoalType.AID)
			{
				currentStrategy = getAidStrategy(character, goal);
			}
			// new survive strategy
			else
			{
				currentStrategy = getSurviveStrategy(character, goal);
			}
		}
		
		// set the current goal
		currentGoal = goal;
		
		//System.out.println(character.getName() + " - Current goal : " + goal.getPrintable());
		//System.out.println(character.getName() + " - Current strategy : " + currentStrategy.getStrategyName());
		//System.out.println(character.getName() + " - Current state : " + currentStrategy.getStateMachine().getCurrentState().getName());
		
		currentStrategy.update(delta);
	}

	/**
	 * Handle ai events
	 * @param aievent the event
	 */
	public void eventHandler(AIEvent aievent) {
		GoalManager goalManager = character.getGoalManager();
		goalManager.handleEvent(aievent);
	}
	
	/**
	 * Get the attack strategy
	 * @param character the character to whom the strategy belongs
	 * @param goal the goal of the strategy
	 * @return the attack strategy
	 */
	public ModeStrategy getAttackStrategy(Character character, Goal goal)
	{
		return null;
	}
	
	/**
	 * Get the aid strategy
	 * @param character the character to whom the strategy belongs
	 * @param goal the goal of the strategy
	 * @return the aid strategy
	 */
	public ModeStrategy getAidStrategy(Character character, Goal goal)
	{
		return null;
	}
	
	/**
	 * Get the survive strategy
	 * @param character the character to whom the strategy belongs
	 * @param goal the goal of the strategy
	 * @return the survive strategy
	 */
	public ModeStrategy getSurviveStrategy(Character character, Goal goal)
	{
		return null;
	}
	
}
