/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.mage;

import gameobject.character.Character;
import strategy.Goal;
import strategy.ModeStrategy;
import strategy.Strategy;

/**
 * This class represents a strategy for the mage
 * @author jordan
 * @version Feb 2 2014
 */
public class MageStrategy extends Strategy {

	/**
	 * Constructor
	 * @param character the character to whom this strategy belongs
	 */
	public MageStrategy(Character character) {
		super(character);
		// TODO: add goals to goal manager
	}
	
	/*
	 * @see strategy.Strategy#getAttackStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getAttackStrategy(Character character, Goal goal)
	{
		return new MageAttackStrategy(character, goal);
	}
	
	/*
	 * @see strategy.Strategy#getAidStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getAidStrategy(Character character, Goal goal)
	{
		return new MageAidStrategy(character, goal);
	}
	
	/*
	 * @see strategy.Strategy#getSurviveStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getSurviveStrategy(Character character, Goal goal)
	{
		return new MageSurviveStrategy(character, goal);
	}

}
