/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.mage;

import strategy.Goal;
import strategy.ModeStrategy;
import strategy.statemachine.State;
import strategy.statemachine.Transition;
import strategy.statemachine.actions.FleeAction;
import strategy.statemachine.actions.IdleAction;
import strategy.statemachine.actions.WarriorSeekAction;
import strategy.statemachine.conditions.HasReachedSafePlace;
import strategy.statemachine.conditions.HasReachedTarget;
import strategy.statemachine.conditions.HasYetToReachSafePlace;
import strategy.statemachine.conditions.HasYetToReachTarget;
import gameobject.character.Character;

/**
 * This class represents the mage's strategy for surviving
 * @author jordan
 * @version Feb 2 2014
 */
public class MageSurviveStrategy extends ModeStrategy {

	/**
	 * Constructor
	 * @param character the character to whom this strategy belongs
	 * @param goal the goal associated with the strategy
	 */
	public MageSurviveStrategy(Character character, Goal goal)
	{
		super(character, goal);
		strategyName = "Mage survive strategy";

		// seek state
		State flee = new State("Flee");
		// idle state
		State idle = new State("Idle");

		// add transitions to flee
		// has reached safe place
		flee.addTransition(new Transition(new HasReachedSafePlace(character),
				new IdleAction(character), idle));
		// hasn't reached safe place yet
		flee.addTransition(new Transition(new HasYetToReachSafePlace(character),
				new FleeAction(character), flee));

		// add transitions to idle
		// still at target
		idle.addTransition(new Transition(new HasReachedSafePlace(character),
				new IdleAction(character), idle));
		// target has moved away
		idle.addTransition(new Transition(new HasYetToReachSafePlace(character),
				new FleeAction(character), flee));

		// add states to state machine
		stateMachine.addState(flee);
		stateMachine.addState(idle);
		// set the starting state
		stateMachine.setCurrentState(flee);
	}

}
