/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.rogue;

import strategy.Goal;
import strategy.ModeStrategy;
import strategy.statemachine.State;
import strategy.statemachine.Transition;
import strategy.statemachine.actions.IdleAction;
import strategy.statemachine.actions.RogueAttackAction;
import strategy.statemachine.actions.RogueSeekAction;
import strategy.statemachine.actions.WarriorSeekAction;
import strategy.statemachine.conditions.HasReachedDestination;
import strategy.statemachine.conditions.HasReachedTarget;
import strategy.statemachine.conditions.HasYetToReachDestination;
import strategy.statemachine.conditions.HasYetToReachTarget;
import gameobject.character.Character;

/**
 * This class represents the rogue's strategy for attacking
 * @author jordan
 * @version Feb 2 2014
 */
public class RogueAttackStrategy extends ModeStrategy {

	/**
	 * Constructor
	 * @param character the character to whom this strategy belongs
	 * @param goal the goal associated with the strategy
	 */
	public RogueAttackStrategy(Character character, Goal goal)
	{
		super(character, goal);
		strategyName = "Rogue attack strategy";

		// seek state
		State seek = new State("Seek");
		// idle state
		State idle = new State("Idle");

		// add transitions to seek
		// has reached target
		seek.addTransition(new Transition(new HasReachedDestination(character),
				new RogueAttackAction(character), idle));
		// hasn't reach target yet
		seek.addTransition(new Transition(new HasYetToReachDestination(character),
				new RogueSeekAction(character), seek));

		// add transitions to idle
		// still at target
		idle.addTransition(new Transition(new HasReachedDestination(character),
				new RogueAttackAction(character), idle));
		// target has moved away
		idle.addTransition(new Transition(new HasYetToReachDestination(character),
				new RogueSeekAction(character), seek));

		// add states to state machine
		stateMachine.addState(seek);
		stateMachine.addState(idle);
		// set the starting state
		stateMachine.setCurrentState(idle);
	}

}
