/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.rogue;

import gameobject.character.Character;
import strategy.Goal;
import strategy.ModeStrategy;
import strategy.Strategy;

/**
 * This class represents a strategy for the rogue
 * @author jordan
 * @version Feb 2 2014
 */
public class RogueStrategy extends Strategy {

	/**
	 * Constructor
	 * @param character the character to whom this strategy belongs
	 */
	public RogueStrategy(Character character) {
		super(character);
		// TODO: add goals to goal manager
	}
	
	/*
	 * @see strategy.Strategy#getAttackStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getAttackStrategy(Character character, Goal goal)
	{
		return new RogueAttackStrategy(character, goal);
	}
	
	/*
	 * @see strategy.Strategy#getAidStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getAidStrategy(Character character, Goal goal)
	{
		return new RogueAidStrategy(character, goal);
	}
	
	/*
	 * @see strategy.Strategy#getSurviveStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getSurviveStrategy(Character character, Goal goal)
	{
		return new RogueSurviveStrategy(character, goal);
	}

}
