/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine;

import java.util.ArrayList;

/**
 * A class representing a state within a state machine
 * @author jordan
 * @version Jan 26 2014
 */
public class State {
	
	private ArrayList<Transition> transitions;
	
	private String name;

	/**
	 * Constructor
	 */
	public State(String name)
	{
		this.name = name;
		transitions = new ArrayList<Transition>();
	}
	
	/**
	 * Add a new transition to the state
	 * The transitions should be added in order of priority, from high to low
	 * @param transition the new transition
	 */
	public void addTransition(Transition transition)
	{
		transitions.add(transition);
	}
	
	/**
	 * Update the state
	 * @param delta the time since the last update
	 */
	public State update(float delta)
	{
		// check all conditions
		for(Transition transition : transitions)
		{
			// if the condition is true
			if(transition.checkCondition())
			{
				// perform the action
				transition.performAction();
				
				// transition to new state
				return transition.getNewState();
			}
		}
		
		return this;
	}
	
	/**
	 * Gets the name of this state
	 * @return the name of the state
	 */
	public String getName()
	{
		return name;
	}
	
}
