/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine;

import java.util.ArrayList;

/**
 * A class representing a finite state automaton
 * @author jordan
 * @version Jan 26 2014
 */
public class StateMachine {
	
	private ArrayList<State> states;
	
	private State currentState;

	/**
	 * Constructor
	 */
	public StateMachine()
	{
		states = new ArrayList<State>();
	}
	
	/**
	 * Sets the current state. Should always be called after setting up the
	 * StateMachine and before first calling update.
	 * @param state
	 */
	public void setCurrentState(State state)
	{
		currentState = state;
	}
	
	/**
	 * Get the current state
	 * @return currentState
	 */
	public State getCurrentState()
	{
		return currentState;
	}
	
	/**
	 * Add a new state to the state machine
	 * @param state the new state
	 */
	public void addState(State state)
	{
		states.add(state);
	}
	
	/**
	 * Update the state machine
	 * @param delta the time since the last update
	 */
	public void update(float delta)
	{
		currentState = currentState.update(delta);
	}
	
}
