/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine;

import strategy.statemachine.actions.ActionFunction;
import strategy.statemachine.conditions.ConditionFunction;

/**
 * A class representing a transition between states in a state machine
 * @author jordan
 * @version Jan 26 2014
 */
public class Transition {
	
	// container for condition function
	// if the condition function returns true, the transition occurs
	private ConditionFunction condition;
	
	// container for the action function
	// the action occurs if the transition occurs
	private ActionFunction action;
	
	// the state to be transitioned to
	// the old state transitions to the new state after the transition action is over
	private State newState;

	/**
	 * Constructor
	 * @param condition container for condition function to be checked against
	 * @param action
	 * @param newState
	 */
	public Transition(ConditionFunction condition, ActionFunction action, State newState)
	{
		this.condition = condition;
		this.action = action;
		this.newState = newState;
	}
	
	/**
	 * Checks if the condition is true
	 * @return true if condition is true, false otherwise
	 */
	public boolean checkCondition()
	{
		// if the condition was initialized as null, then the transition should occur
		if(condition == null){
			return true;
		}
		// otherwise, check the condition
		else
		{
			return condition.checkCondition();
		}
	}
	
	/**
	 * Performs the action
	 */
	public void performAction()
	{
		action.performAction();
	}
	
	/**
	 * Gets the new state
	 * @return the new state
	 */
	public State getNewState()
	{
		return newState;
	}
	
}
