/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.actions;

import pathfinding.GraphNode;
import pathfinding.PathFinder;
import strategy.GoalManager;
import game.GameUtility;
import gameobject.GameObject;
import gameobject.character.Character;
import gameobject.character.Direction;

/**
 * Container for seek action
 * @author jordan
 * @version Jan 26 2014
 */
public class MageHealAction implements ActionFunction {

	private Character character;

	/**
	 * Constructor
	 * @param character the character to whom this action belongs
	 */
	public MageHealAction(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ActionFunction#performAction()
	 */
	@Override
	public void performAction() {

		GoalManager goalmanager = character.getGoalManager();
		GameObject target = goalmanager.getCurrentGoal().getTarget();

		float targetX = target.getX();
		float targetY = target.getY();

		Direction direction = GameUtility.getDirection(character, targetX, targetY);

		Character cTarget = (Character) target;

		if(cTarget.getHealth() < cTarget.getMaxHealth())
		{
			// facing right
			if(direction == Direction.RIGHT)
			{
				character.setSpecialRight(true);
				character.setSpecialLeft(false);
			}
			// facing left
			else if(direction == Direction.LEFT)
			{
				character.setSpecialRight(false);
				character.setSpecialLeft(true);
			}
			// facing up
			else if(direction == Direction.UP)
			{
				character.setSpecialUp(true);
				character.setSpecialDown(false);
			}
			// facing down
			else
			{
				character.setSpecialUp(false);
				character.setSpecialDown(true);
			}
		}

	}

}
