/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.actions;

import pathfinding.GraphNode;
import pathfinding.PathFinder;
import strategy.GoalManager;
import game.GameUtility;
import gameobject.GameObject;
import gameobject.ObjectType;
import gameobject.character.Character;
import gameobject.character.Direction;

/**
 * Container for rogue attack action
 * @author jordan
 * @version Jan 26 2014
 */
public class RogueAttackAction implements ActionFunction {

	private Character character;

	private float PROJECTILE_SPEED = 0.006f;

	/**
	 * Constructor
	 * @param character the character to whom this action belongs
	 */
	public RogueAttackAction(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ActionFunction#performAction()
	 */
	@Override
	public void performAction() {

		GoalManager goalmanager = character.getGoalManager();
		GameObject target = goalmanager.getCurrentGoal().getTarget();

		// figure out where the rogue should aim

		// calculate how long it takes for projectile to travel distance
		float dist = GameUtility.getStraightLineDistance(character.getCenterX(),
				character.getCenterY(), target.getCenterX(), character.getCenterY());
		float time = dist/PROJECTILE_SPEED;

		// figure out how far the targe will travel in that time (if it's moving)
		float xLead = 0;
		float yLead = 0;
		if(target.getObjectType() == ObjectType.ENEMY)
		{
			Character cTarget = (Character) target;
			
			float targetDist = time*cTarget.getSpeed();

			// moving straight
			if(cTarget.isMovingRight()) xLead = targetDist;
			if(cTarget.isMovingLeft()) xLead = -targetDist;
			if(cTarget.isMovingUp()) yLead = targetDist;
			if(cTarget.isMovingDown()) yLead = -targetDist;

			// moving diagonally
			if(cTarget.isMovingRight() && cTarget.isMovingUp())
			{
				xLead = (float) (targetDist*Math.cos(Math.PI/4));
				yLead = (float) (targetDist*Math.sin(Math.PI/4));
			}
			if(cTarget.isMovingRight() && cTarget.isMovingDown())
			{
				xLead = (float) (targetDist*Math.cos(Math.PI/4));
				yLead = (float) (-targetDist*Math.sin(Math.PI/4));
			}
			if(cTarget.isMovingLeft() && cTarget.isMovingUp())
			{
				xLead = (float) (-targetDist*Math.cos(Math.PI/4));
				yLead = (float) (targetDist*Math.sin(Math.PI/4));
			}
			if(cTarget.isMovingLeft() && cTarget.isMovingDown())
			{
				xLead = (float) (-targetDist*Math.cos(Math.PI/4));
				yLead = (float) (-targetDist*Math.sin(Math.PI/4));
			}
		}

		float cursorX = target.getCenterX() + xLead;
		float cursorY = target.getCenterY() + yLead;
		
		Direction direction = GameUtility.getDirection(character, cursorX, cursorY);
		
		character.setCursorX(cursorX);
		character.setCursorY(cursorY);
		
		character.setAttackingRight(false);
		character.setAttackingLeft(false);
		character.setAttackingUp(false);
		character.setAttackingDown(false);
		character.setMovingLeft(false);
		character.setMovingRight(false);
		character.setMovingUp(false);
		character.setMovingDown(false);
		// facing right
		if(direction == Direction.RIGHT)
		{
			character.setAttackingRight(true);
		}
		// facing left
		else if(direction == Direction.LEFT)
		{
			character.setAttackingLeft(true);
		}
		// facing up
		else if(direction == Direction.UP)
		{
			character.setAttackingUp(true);
		}
		// facing down
		else
		{
			character.setAttackingDown(true);
		}

	}

}
