/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.actions;

import java.util.ArrayList;

import pathfinding.Graph;
import pathfinding.GraphNode;
import pathfinding.PathFinder;
import strategy.GoalManager;
import game.GameScreen;
import game.QuestMain;
import gameobject.GameObject;
import gameobject.character.Character;

/**
 * Container for the rogue's seek action
 * @author jordan
 * @version Jan 26 2014
 */
public class RogueSeekAction implements ActionFunction {

	private Character character;

	/**
	 * Constructor
	 * @param character the character to whom this action belongs
	 */
	public RogueSeekAction(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ActionFunction#performAction()
	 */
	@Override
	public void performAction() {

		GoalManager goalManager = character.getGoalManager();
		GameObject target = goalManager.getCurrentGoal().getTarget();
		Graph graph = QuestMain.getCurrentScreen().getGraph();
		GraphNode destination = graph.getNearestNode(target.getCenterX(), target.getCenterY());

		float characterX = character.getX();
		float characterY = character.getY();

		GameScreen gameScreen = QuestMain.getCurrentScreen();
		ArrayList<GameObject> collisions = gameScreen.castRay(characterX, characterY, destination.getX(),
				destination.getY());
		collisions.remove(character);

		float seekX;
		float seekY;

		// have line of sight to target
		if(collisions.isEmpty())
		{
			seekX = destination.getX();
			seekY = destination.getY();
		}
		// need to follow path
		else
		{
			// get the node
			PathFinder pathfinder = character.getPathfinder();
			GraphNode node = pathfinder.getCurrentNode(destination);

			seekX = node.getX();
			seekY = node.getY();
		}

		// moving right
		if(seekX >= characterX)
		{
			character.setMovingRight(true);
			character.setMovingLeft(false);
		}
		// moving left
		else
		{
			character.setMovingLeft(true);
			character.setMovingRight(false);
		}

		// moving up
		if(seekY >= characterY)
		{
			character.setMovingUp(true);
			character.setMovingDown(false);
		}
		// moving down
		else
		{
			character.setMovingDown(true);
			character.setMovingUp(false);
		}

		character.setAttackingLeft(false);
		character.setAttackingRight(false);
		character.setAttackingUp(false);
		character.setAttackingDown(false);
	}
}
