/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.actions;

import pathfinding.GraphNode;
import pathfinding.PathFinder;
import strategy.GoalManager;
import game.GameUtility;
import gameobject.GameObject;
import gameobject.character.Character;
import gameobject.character.Direction;

/**
 * Container for seek action
 * @author jordan
 * @version Jan 26 2014
 */
public class WarriorAttackAction implements ActionFunction {

	private Character character;

	/**
	 * Constructor
	 * @param character the character to whom this action belongs
	 */
	public WarriorAttackAction(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ActionFunction#performAction()
	 */
	@Override
	public void performAction() {

		GoalManager goalmanager = character.getGoalManager();
		GameObject target = goalmanager.getCurrentGoal().getTarget();

		float targetX = target.getX();
		float targetY = target.getY();
		
		Direction direction = GameUtility.getDirection(character, targetX, targetY);

		// facing right
		if(direction == Direction.RIGHT)
		{
			character.setAttackingRight(true);
			character.setAttackingLeft(false);
		}
		// facing left
		else if(direction == Direction.LEFT)
		{
			character.setAttackingRight(false);
			character.setAttackingLeft(true);
		}
		// facing up
		else if(direction == Direction.UP)
		{
			character.setAttackingUp(true);
			character.setAttackingDown(false);
		}
		// facing down
		else
		{
			character.setAttackingUp(false);
			character.setAttackingDown(true);
		}

	}

}
