/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.actions;

import java.util.ArrayList;

import pathfinding.GraphNode;
import pathfinding.PathFinder;
import strategy.GoalManager;
import game.GameScreen;
import game.GameUtility;
import game.QuestMain;
import gameobject.GameObject;
import gameobject.ObjectType;
import gameobject.character.Character;
import gameobject.character.Direction;

/**
 * Container for seek action
 * @author jordan
 * @version Jan 26 2014
 */
public class WarriorSeekAction implements ActionFunction {

	private Character character;

	private float TARGET_TOLERANCE = 0.1f;

	/**
	 * Constructor
	 * @param character the character to whom this action belongs
	 */
	public WarriorSeekAction(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ActionFunction#performAction()
	 */
	@Override
	public void performAction() {

		GoalManager goalManager = character.getGoalManager();
		GameObject target = goalManager.getCurrentGoal().getTarget();

		float characterX = character.getX();
		float characterY = character.getY();

		float targetX = target.getX();
		float targetY = target.getY();

		if(target.getObjectType() == ObjectType.ENEMY)
		{
			Character cTarget = (Character) target;
			
			// get closest flank point
			float[] flankRight = cTarget.getAttackPoint(Direction.RIGHT);
			float[] flankLeft = cTarget.getAttackPoint(Direction.LEFT);
			float[] backstab = cTarget.getAttackPoint(Direction.DOWN);

			float[] closest = flankRight;
			float bestDist = GameUtility.getStraightLineDistance(characterX, characterY, flankRight[0], flankRight[1]);
			float leftDist = GameUtility.getStraightLineDistance(characterX, characterY, flankLeft[0], flankLeft[1]);
			float backDist = GameUtility.getStraightLineDistance(characterX, characterY, backstab[0], backstab[1]);
			if(leftDist < bestDist)
			{
				closest = flankLeft;
				bestDist = leftDist;
			}
			if(backDist < bestDist)
			{
				closest = backstab;
				bestDist = backDist;
			}
			
			targetX = closest[0];
			targetY = closest[1];
		}

		float diffX = targetX - characterX;
		float diffY = targetY - characterY;

		float dist = Math.abs(diffX*diffX + diffY*diffY);

		GameScreen gameScreen = QuestMain.getCurrentScreen();
		ArrayList<GameObject> collisions = gameScreen.castRay(characterX, characterY, targetX,
				targetY);
		collisions.remove(character);

		float seekX;
		float seekY;

		// have line of sight to target
		if(collisions.isEmpty())
		{
			seekX = targetX;
			seekY = targetY;
		}
		// need to follow path
		else
		{
			// get the node
			PathFinder pathfinder = character.getPathfinder();
			GraphNode node = pathfinder.getCurrentNode(target);

			seekX = node.getX();
			seekY = node.getY();
		}

		// moving right
		if(seekX >= characterX)
		{
			character.setMovingRight(true);
			character.setMovingLeft(false);
		}
		// moving left
		else
		{
			character.setMovingLeft(true);
			character.setMovingRight(false);
		}

		// moving up
		if(seekY >= characterY)
		{
			character.setMovingUp(true);
			character.setMovingDown(false);
		}
		// moving down
		else
		{
			character.setMovingDown(true);
			character.setMovingUp(false);
		}

		character.setAttackingLeft(false);
		character.setAttackingRight(false);
		character.setAttackingUp(false);
		character.setAttackingDown(false);
	}
}
