/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.conditions;

import pathfinding.Graph;
import pathfinding.GraphNode;

import com.badlogic.gdx.math.Circle;

import strategy.Goal;
import strategy.GoalManager;
import game.QuestMain;
import gameobject.GameObject;
import gameobject.character.Character;

/**
 * Character has reached destination
 * @author jordan
 * @version Jan 26 2014
 */
public class HasReachedSafePlace implements ConditionFunction {

	private Character character;

	/**
	 * Constructor
	 * @param character the character to whom this condition belongs
	 */
	public HasReachedSafePlace(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ConditionFunction#checkCondition()
	 */
	@Override
	public boolean checkCondition() {
		
		Graph graph = QuestMain.getCurrentScreen().getGraph();
		GraphNode destination = graph.findSafePlace(character);

		// check if the character has reached the destination
		if(character.getCollider().contains(destination.getX(), destination.getY()))
		{
			return true;
		}

		return false;
	}

}
