/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.conditions;

import java.util.ArrayList;

import pathfinding.Graph;
import pathfinding.GraphNode;
import strategy.Goal;
import strategy.GoalManager;
import game.GameScreen;
import game.QuestMain;
import gameobject.GameObject;
import gameobject.character.Character;

/**
 * Character has yet to reach target
 * @author jordan
 * @version Jan 26 2014
 */
public class HasYetToReachDestination implements ConditionFunction {

	private Character character;

	/**
	 * Constructor
	 * @param character the character to whom this condition belongs
	 */
	public HasYetToReachDestination(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ConditionFunction#checkCondition()
	 */
	@Override
	public boolean checkCondition() {
		GoalManager goalManager = character.getGoalManager();
		Goal goal = goalManager.getCurrentGoal();
		GameObject target = goal.getTarget();
		
		GameScreen gameScreen = QuestMain.getCurrentScreen();
		ArrayList<GameObject> collisions1 = gameScreen.castRay(character.getCenterX(), character.getCenterY(),
				target.getCenterX(), target.getCenterY());
		ArrayList<GameObject> collisions2 = gameScreen.castRay(character.getX(), character.getY(),
				target.getX(), target.getY());
		collisions1.remove(character);
		collisions1.remove(target);
		collisions2.remove(character);
		collisions2.remove(target);

		// check if the character has reached the destination
		if(!collisions1.isEmpty() || !collisions2.isEmpty())
		{
			return true;
		}

		return false;
	}

}
