/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.statemachine.conditions;

import com.badlogic.gdx.math.Circle;

import strategy.Goal;
import strategy.GoalManager;
import strategy.statemachine.conditions.ConditionFunction;
import gameobject.GameObject;
import gameobject.character.Character;

/**
 * Character has reached target
 * @author jordan
 * @version Jan 26 2014
 */
public class IsInAttackRange implements ConditionFunction {

	private Character character;

	/**
	 * Constructor
	 * @param character the character to whom this condition belongs
	 */
	public IsInAttackRange(Character character)
	{
		this.character = character;
	}

	/*
	 * @see strategy.ConditionFunction#checkCondition()
	 */
	@Override
	public boolean checkCondition() {
		GoalManager goalManager = character.getGoalManager();
		Goal goal = goalManager.getCurrentGoal();
		GameObject target = goal.getTarget();

		// if character has reached target
		Circle charZone = character.getAttackRange();
		if(charZone.contains(target.getCenterX(), target.getCenterY()))
		{
			return true;
		}
		return false;
	}

}
