/*******************************************************************************
 * This file was developed for an MQP project at Worcester Polytechnic Institute.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/

package strategy.warrior;

import strategy.Goal;
import strategy.ModeStrategy;
import strategy.Strategy;
import gameobject.character.Character;

/**
 * This class represents a strategy for the warrior
 * @author jordan
 * @version Feb 2 2014
 */
public class WarriorStrategy extends Strategy {
	
	/**
	 * Constructor
	 * @param character the character to whom this strategy belongs
	 */
	public WarriorStrategy(Character character)
	{
		super(character);
		// TODO: add goals to goal manager
	}
	
	/*
	 * @see strategy.Strategy#getAttackStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getAttackStrategy(Character character, Goal goal)
	{
		return new WarriorAttackStrategy(character, goal);
	}
	
	/*
	 * @see strategy.Strategy#getAidStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getAidStrategy(Character character, Goal goal)
	{
		return new WarriorAidStrategy(character, goal);
	}
	
	/*
	 * @see strategy.Strategy#getSurviveStrategy(gameobject.character.Character, strategy.Goal)
	 */
	@Override
	public ModeStrategy getSurviveStrategy(Character character, Goal goal)
	{
		return new WarriorSurviveStrategy(character, goal);
	}

}
